/*
 *
 *	Preferencias de Gestion
 *
 *	(C) 2007 Alvaro Cortes.
 *
 *	Clase de gestion de la preferencias locales
 *	de la aplicacin.
 *
 */

using System;

namespace Formulacion{
	
/// <summary>
/// Manejo de la preferencias de gestion de la aplicacion: Factor P e IVA.
/// </summary>
class PreferenciasGestion{

	public string strFichero;
	System.Xml.XmlTextWriter salidaXml;
	System.Xml.XmlTextReader entradaXml;
	bool salidaAbierta = false;
	bool entradaAbierta = false;

	#region Asignaciones de propiedades
	/// <summary>
	/// Asigna el nombre del fichero de configuracion.
	/// </summary>
	/// <param name="strNombre">Nombre del fichero</param>
	public void AsignarNmbFichero(string strNombre){

	if(  strNombre != null)
	strFichero = strNombre;
	else
	strFichero = "FMConfig.xml";
	}

	#endregion
	
	#region Operaciones de fichero
	/// <summary>
	/// Crea el fichero de configuracion inicial.
	/// </summary>
	public void CrearFichero(){

	try{
		
	salidaXml = new System.Xml.XmlTextWriter(strFichero, 
			System.Text.Encoding.UTF8);

		salidaXml.Formatting = System.Xml.Formatting.Indented;
		salidaXml.WriteStartDocument();
		salidaXml.WriteStartElement("FMConfiguracion","uri:FM");
		salidaXml.WriteAttributeString("AppName",
			"FormulacionMagistral");
		salidaXml.WriteAttributeString("Version","0.0.1");
		salidaAbierta = true;
	}catch(Exception e){
		FM_Errores.MostrarError("CrearFichero","No se ha podido crear el fichero XML",e);
	}

	}
	
	/// <summary>Cierra la entrada de datos</summary>
	public void CerrarEntrada(){
		entradaXml.Close();
	}
	
	/// <summary>
	/// Cierra el fichero de configuracion
	/// </summary>
	public void CerrarFichero(){

	try{
		if( salidaAbierta)
		{
			salidaXml.WriteEndElement();
			salidaXml.WriteEndDocument();
			salidaXml.Flush();
			salidaXml.Close();
			salidaAbierta = false;
		}

	}catch(Exception e){
		FM_Errores.MostrarError("CerrarFichero","No se ha podido cerrar el fichero XML",e);
	}

	}
	#endregion
	
	#region Metodos de carga y descarga de configuracin
	/// <summary>
	/// Carga la informacion del factorp e IVA
	/// </summary>
	/// <param name="factorP">Numero decimal del factor P</param>
	/// <param name="IVA">Porcentaje de IVA a aplicar</param>
	/// <param name="provincia">Provincia actual</param>
	/// <param name="annus">ao actual</param>
	public void GuardarPreferenciasGestion(float factorP, float IVA, string provincia, string annus){
	try{
		if( salidaAbierta )
		{
		salidaXml.WriteStartElement("Gestion","uri:FM");
		salidaXml.WriteElementString("FactorP","uri:FM",factorP.ToString());
		salidaXml.WriteElementString("IVA","uri:FM",IVA.ToString());
		salidaXml.WriteElementString("Provincia","uri:FM",provincia);
		salidaXml.WriteElementString("Annus","uri:FM",annus);
		salidaXml.WriteEndElement();
		salidaXml.Flush();
		}
	}catch(Exception e){
		FM_Errores.MostrarError("GuardarPreferenciasGestion","No se puede guardar la informacion en el fichero XML.",e);
	}
	}

	/// <summary>
	/// Carga el fichero Xml en un XmlTextReader
	/// </summary>
	public bool LeerFichero(){
	try{
	entradaXml = new System.Xml.XmlTextReader(strFichero);
	entradaXml.XmlResolver = null;
	entradaAbierta = true;
	return true;
	}catch(Exception e){
		FM_Errores.MostrarError("LeerFichero","No se puede leer el fichero XML",e);
		return false;
	}
	}

	/// <summary>
	/// Devuelve un array de tipo string de longitud igual a 2
	/// que contiene los datos necesarios para gestion de la aplicacion
	/// </summary>
	/// <returns>Devuelve un array de string con la siguiente estructura: El elemento 0 es el Factor P, el elemento 1 es el porcentaje de IVA.</returns>
	public string[] CargarPreferenciasGestion(){

	string[] pref = new string[4];
	int indstr = 0;
	System.Xml.XmlNodeType nodotipo;

	try{ 

	if( entradaAbierta)
	{
	entradaXml.Read();
	while(entradaXml.Read())
	{
		entradaXml.MoveToElement();
		nodotipo = entradaXml.NodeType;
		if( nodotipo == System.Xml.XmlNodeType.Element)
		{
			if( System.String.Compare("FactorP",entradaXml.Name.ToString(),
				true) == 0)
				indstr = 0;
			else if(System.String.Compare("IVA",
				entradaXml.Name.ToString(),true) == 0)
				indstr = 1;
			else if(System.String.Compare("Provincia",
				entradaXml.Name.ToString(),true) == 0)
				indstr = 2;
			else if(System.String.Compare("Annus",
				entradaXml.Name.ToString(),true) == 0)
				indstr = 3;
		}
			if( nodotipo == System.Xml.XmlNodeType.Text )
				pref[indstr] = entradaXml.Value.ToString();
	}
	return pref;
	}
	return pref;

	}catch(Exception e){
		FM_Errores.MostrarError("CargarPreferenciasGestion","No se ha podido cargar la informacion del archivo XML",e);
	return pref;
	}
}
	#endregion
	
	
} // Fin de la Clase Preferencias

} // Fin Namespace
