/*
 * Prefs Info
 * 
 * 
 * (C) Alvaro Cortes. 2007. alvarocortesc@gmail.com
 * 
 * Maneja la informacin sobre el establecimiento que gestiona el programa
 * 
 */

using System;

namespace Formulacion
{
	/// <summary>
	/// Carga y guarda la informacion sobre el servicio a gestionar
	/// </summary>
	public class PreferenciasServicio
	{
			/// <summary>
			/// Nombre del fichero a utilizar
			/// </summary>
			public string strFichero;
			System.Xml.XmlTextWriter salidaXml;
			System.Xml.XmlTextReader entradaXml;
			bool salidaAbierta = false;
			bool entradaAbierta = false;

		
	#region Asignaciones de propiedades
		/// <summary>
		/// Asigna el nombre del fichero de configuracion.
		/// </summary>
		/// <param name="strNombre">Nombre del fichero</param>
		public void AsignarNmbFichero(string strNombre)
		{
			if(  strNombre != null)
				strFichero = strNombre;
			else
				strFichero = "FMServicio.xml";
		}

		#endregion
	
		
	#region Operaciones de fichero
	/// <summary>
	/// Crea el fichero de configuracion inicial.
	/// </summary>
	public void CrearFichero(){

	try{
		
	salidaXml = new System.Xml.XmlTextWriter(strFichero, 
			System.Text.Encoding.UTF8);

		salidaXml.Formatting = System.Xml.Formatting.Indented;
		salidaXml.WriteStartDocument();
		salidaXml.WriteStartElement("FMServicio","uri:FM");
		salidaXml.WriteAttributeString("AppName",
			"FormulacionMagistral");
		salidaXml.WriteAttributeString("Version","0.0.1");
		salidaAbierta = true;
	}catch(Exception e){
		FM_Errores.MostrarError("CrearFichero","No se ha podido crear el fichero XML",e);
	}

	}
	
	/// <summary>Cierra la entrada de datos</summary>
	public void CerrarEntrada(){
		entradaXml.Close();
	}
	
	/// <summary>
	/// Cierra el fichero de configuracion
	/// </summary>
	public void CerrarFichero(){

	try{
		if( salidaAbierta)
		{
			salidaXml.WriteEndElement();
			salidaXml.WriteEndDocument();
			salidaXml.Flush();
			salidaXml.Close();
			salidaAbierta = false;
		}

	}catch(Exception e){
		FM_Errores.MostrarError("CerrarFichero","No se ha podido cerrar el fichero XML",e);
	}

	}
	#endregion


	#region Metodos de carga y descarga de configuracin
	/// <summary>
	/// Guarda la informacion del serivicio
	/// </summary>
	/// <param name="nombre">Nombre del servicio</param>
	/// <param name="direccion">Direccion del servicio</param>
	/// <param name="ldo">Ldo al cargo</param>
	/// <param name="servicio">Tipo de Servicio</param>
	/// <param name="comentarios">Comentarios</param>
	public void GuardarPreferenciasServicio( string nombre, string direccion,
	                                        string ldo, string servicio, string comentarios){
	try{
		if( salidaAbierta )
		{
		salidaXml.WriteStartElement("Servicio","uri:FM");
		salidaXml.WriteElementString("Nombre","uri:FM",nombre);
		salidaXml.WriteElementString("Direccion","uri:FM",direccion);
		salidaXml.WriteElementString("Ldo","uri:FM",ldo);
		salidaXml.WriteElementString("TServicio","uri:FM",servicio);
		salidaXml.WriteElementString("Comentarios","uri:FM",comentarios);
		
		salidaXml.WriteEndElement();
		salidaXml.Flush();
		}
	}catch(Exception e){
		FM_Errores.MostrarError("GuardarPreferenciasServicio","No se puede guardar la informacion en el fichero XML.",e);
	}
	}

	/// <summary>
	/// Carga el fichero Xml en un XmlTextReader
	/// </summary>
	public bool LeerFichero(){
	try{
	entradaXml = new System.Xml.XmlTextReader(strFichero);
	entradaXml.XmlResolver = null;
	entradaAbierta = true;
	return true;
	}catch(Exception e){
		FM_Errores.MostrarError("LeerFichero","No se puede leer el fichero XML",e);
		return false;
	}
	}

	/// <summary>
	/// Devuelve un array de tipo string de longitud igual a 5
	/// que contiene los datos necesarios para conectarse a la base
	/// de datos.
	/// </summary>
	/// <returns>Devuelve un array de string con la siguiente estructura: 
	/// El elemento 0 es el Nombre del servicio
	/// El elemento 1 es la Direccion del servicio
	/// El elemento 2 es el Licenciado
	/// El elemento 3 es el tipo de servicio (Farmacia, etc...)
	/// El elemento 4 son comentarios extras.
	/// </returns>
	public string[] CargarPreferenciasServicio(){

	string[] pref = new string[5];
	int indstr = 0;
	System.Xml.XmlNodeType nodotipo;

	try{ 

	if( entradaAbierta)
	{
	entradaXml.Read();
	while(entradaXml.Read())
	{
		entradaXml.MoveToElement();
		nodotipo = entradaXml.NodeType;
		if( nodotipo == System.Xml.XmlNodeType.Element)
		{
		if( System.String.Compare("Nombre",entradaXml.Name.ToString(),
				true) == 0)
			indstr = 0;
		else if(System.String.Compare("Direccion",
			entradaXml.Name.ToString(),true) == 0)
			indstr = 1;
		else if( System.String.Compare("Ldo",
			entradaXml.Name.ToString(), true) == 0)
			indstr = 2;
		else if( System.String.Compare("TServicio",
			entradaXml.Name.ToString(),true) == 0)
			indstr = 3;
		else if( System.String.Compare("Comentarios",
			entradaXml.Name.ToString(),true) == 0)
			indstr = 4;
		}
		if( nodotipo == System.Xml.XmlNodeType.Text )
		pref[indstr] = entradaXml.Value.ToString();
	}
	return pref;
	}
	return pref;

	}catch(Exception e){
		FM_Errores.MostrarError("CargarPreferenciasServicio","No se ha podido cargar la informacion del archivo XML",e);
	return pref;
	}
}
	#endregion

		
		
	}
}
