/*
 *
 *	Prefs Stuff.
 *
 *	(C) 2006 Alvaro Cortes.
 *
 *	Clase de gestion de la preferencias locales
 *	de la aplicacin.
 *
 */

using System;

namespace Formulacion{

class PreferenciasDB{

	public string strFichero;
	System.Xml.XmlTextWriter salidaXml;
	System.Xml.XmlTextReader entradaXml;
	bool salidaAbierta = false;
	bool entradaAbierta = false;

	#region Asignaciones de propiedades
	/// <summary>
	/// Asigna el nombre del fichero de configuracion.
	/// </summary>
	/// <param name="strNombre">Nombre del fichero</param>
	public void AsignarNmbFichero(string strNombre){

	if(  strNombre != null)
	strFichero = strNombre;
	else
	strFichero = "FMConfig.xml";
	}

	#endregion
	
	#region Operaciones de fichero
	/// <summary>
	/// Crea el fichero de configuracion inicial.
	/// </summary>
	public void CrearFichero(){

	try{
		
	salidaXml = new System.Xml.XmlTextWriter(strFichero, 
			System.Text.Encoding.UTF8);

		salidaXml.Formatting = System.Xml.Formatting.Indented;
		salidaXml.WriteStartDocument();
		salidaXml.WriteStartElement("FMConfiguracion","uri:FM");
		salidaXml.WriteAttributeString("AppName",
			"FormulacionMagistral");
		salidaXml.WriteAttributeString("Version","0.0.1");
		salidaAbierta = true;
	}catch(Exception e){
		FM_Errores.MostrarError("CrearFichero","No se ha podido crear el fichero XML",e);
	}

	}
	
	/// <summary>Cierra la entrada de datos</summary>
	public void CerrarEntrada(){
		entradaXml.Close();
	}
	
	/// <summary>
	/// Cierra el fichero de configuracion
	/// </summary>
	public void CerrarFichero(){

	try{
		if( salidaAbierta)
		{
			salidaXml.WriteEndElement();
			salidaXml.WriteEndDocument();
			salidaXml.Flush();
			salidaXml.Close();
			salidaAbierta = false;
		}

	}catch(Exception e){
		FM_Errores.MostrarError("CerrarFichero","No se ha podido cerrar el fichero XML",e);
	}

	}
	#endregion
	
	#region Metodos de carga y descarga de configuracin
	/// <summary>
	/// Guarda la informacion de la base de datos.
	/// </summary>
	/// <param name="host">Nombre del servidor</param>
	/// <param name="port">Puerto del servidor</param>
	/// <param name="username">Usuario para acceso a la BD</param>
	/// <param name="pasoteword">Password del usuario</param>
	/// <param name="dbname">Nombre de la base de datos</param>
	public void GuardarPreferenciasDB( string host, string port, 
		string username, string pasoteword, string dbname){
	try{
		if( salidaAbierta )
		{
		salidaXml.WriteStartElement("Database","uri:FM");
		salidaXml.WriteElementString("Host","uri:FM",host);
		salidaXml.WriteElementString("Port","uri:FM",port);
		salidaXml.WriteElementString("User","uri:FM",username);
		salidaXml.WriteElementString("Password","uri:FM",pasoteword);
		salidaXml.WriteElementString("DBName","uri:FM",dbname);
		
		salidaXml.WriteEndElement();
		salidaXml.Flush();
		}
	}catch(Exception e){
		FM_Errores.MostrarError("GuardarPreferenciasDB","No se puede guardar la informacion en el fichero XML.",e);
	}
	}

	/// <summary>
	/// Carga el fichero Xml en un XmlTextReader
	/// </summary>
	public bool LeerFichero(){
	try{
	entradaXml = new System.Xml.XmlTextReader(strFichero);
	entradaXml.XmlResolver = null;
	entradaAbierta = true;
	return true;
	}catch(Exception e){
		FM_Errores.MostrarError("LeerFichero","No se puede leer el fichero XML",e);
		return false;
	}
	}

	/// <summary>
	/// Devuelve un array de tipo string de longitud igual a 5
	/// que contiene los datos necesarios para conectarse a la base
	/// de datos.
	/// </summary>
	/// <returns>Devuelve un array de string con la siguiente estructura: El elemento 0 es el Host, el elemento 1 es el Puerto, el elemento 2 es el Usuario, el elemento 3 es la contrasea y el elemento 4 es el nombre de la base de datos.</returns>
	public string[] CargarPreferenciasDB(){

	string[] pref = new string[5];
	int indstr = 0;
	System.Xml.XmlNodeType nodotipo;

	try{ 

	if( entradaAbierta)
	{
	entradaXml.Read();
	while(entradaXml.Read())
	{
		entradaXml.MoveToElement();
		nodotipo = entradaXml.NodeType;
		if( nodotipo == System.Xml.XmlNodeType.Element)
		{
		if( System.String.Compare("Host",entradaXml.Name.ToString(),
				true) == 0)
			indstr = 0;
		else if(System.String.Compare("Port",
			entradaXml.Name.ToString(),true) == 0)
			indstr = 1;
		else if( System.String.Compare("User",
			entradaXml.Name.ToString(), true) == 0)
			indstr = 2;
		else if( System.String.Compare("Password",
			entradaXml.Name.ToString(),true) == 0)
			indstr = 3;
		else if( System.String.Compare("DBName",
			entradaXml.Name.ToString(),true) == 0)
			indstr = 4;
		}
		if( nodotipo == System.Xml.XmlNodeType.Text )
		pref[indstr] = entradaXml.Value.ToString();
	}
	return pref;
	}
	return pref;

	}catch(Exception e){
		FM_Errores.MostrarError("CargarPreferencias","No se ha podido cargar la informacion del archivo XML",e);
	return pref;
	}
}
	#endregion
	
	
} // Fin de la Clase Preferencias

} // Fin Namespace
