/*
 * AceptacionesForm
 * 
 * 
 * (C) Alvaro Cortes. alvarocortesc@gmail.com
 * 
 * 
 * Gestiona las aceptaciones de materiales, materias primas, etc...
 * 
 */

using System;
using System.Drawing;
using System.Windows.Forms;
using System.Drawing.Printing;
using MySql.Data.MySqlClient;
using System.Data;



namespace FormulacionMagistral
{
	/// <summary>
	/// Description of AceptacionesForm.
	/// </summary>
	public class AceptacionesForm : System.Windows.Forms.Form
	{
		private System.Windows.Forms.Button btnPersonal;
		private System.Windows.Forms.Label lblPos;
		private System.Windows.Forms.Label lblContenido;
		private System.Windows.Forms.Button btnGuardar;
		private System.Windows.Forms.Label lblPersonalID;
		private System.Windows.Forms.TextBox txtFecha;
		private System.Windows.Forms.Label lblAceptacionID;
		private System.Windows.Forms.TextBox txtAceptacionID;
		private System.Windows.Forms.CheckBox chkContenido;
		private System.Windows.Forms.TextBox txtPersonalID;
		private System.Windows.Forms.Label lblFecha;
		
		private MySqlConnection conn;
		private MySqlDataAdapter adap;  
		private System.Data.DataSet ds;
		private MySqlParameter parm;
		
	
		// Algunas variables para emular el CurrencyManager defectuoso de Mono
		private int RecCount;
		private int RecPosition;
				
		// Para cargar preferencias de la BD
		private Formulacion.PreferenciasDB DBPrefs;
		
		// Informacion para conexion BD
		private string dbhost;
		private string dbport;
		private string dbuser;
		private string dbpasoteword;
		
		
		
		// Nivel de acceso
		private int currentlevel;
		private Alertas AlertaLocal; // Alertas

		/// <summary>
		/// Constructor
		/// </summary>
		/// <param name="level">Nivel de acceso</param>
		/// <param name="registro">ID de la aceptacion a cargar. Menor de 0 carga todas</param>
		public AceptacionesForm(int level, int registro)
		{
			//
			// The InitializeComponent() call is required for Windows Forms designer support.
			//
			InitializeComponent();
			
			this.currentlevel = level;
			
			DBPrefs = new Formulacion.PreferenciasDB();
			DBPrefs.AsignarNmbFichero("PrefDataBase.xml");
			
			this.RecPosition = registro;
			AlertaLocal = new Alertas();
		}
		
		/// <summary>
		/// Constructor
		/// </summary>
		/// <param name="level">Nivel de autorizacion</param>
		public AceptacionesForm(int level)
		{
			//
			// The InitializeComponent() call is required for Windows Forms designer support.
			//
			InitializeComponent();
			
			this.currentlevel = level;
			
			DBPrefs = new Formulacion.PreferenciasDB();
			DBPrefs.AsignarNmbFichero("PrefDataBase.xml");
			
			this.RecPosition = -1;
			AlertaLocal = new Alertas();
		}
		
		/// <summary>
		/// Carga la configuracin de la base de datos en la vars
		/// de la clase
		/// </summary>
		void CargarConfiguracionDatabase(){
			string[] prf;
			if ( this.DBPrefs.LeerFichero() )
			{
				prf = this.DBPrefs.CargarPreferenciasDB();
				
				for( int i = 0; i < prf.Length; ++i)
				{
					switch(i){
						case 0: this.dbhost = prf[0]; break;
						case 1: this.dbport = prf[1]; break;
						case 3: this.dbuser = prf[2]; break;
						case 4: this.dbpasoteword = prf[3]; break;
					
					}
				}
				this.DBPrefs.CerrarEntrada();
			}
		}
		
		/// <summary>
		/// Obtiene el id del registro actual
		/// </summary>
		/// <returns>Devuelve un entero del ID del registro</returns>
		public int getcurrentid(){
			int n;
			try{
				n = Convert.ToInt32( this.txtAceptacionID.Text);
				return n;
			}catch(Exception ex){
				FM_Errores.MostrarError("GetCurrentID","No se puede obtener el ID actual",ex);
				return -1;
			}
		}
		
		
		private bool Conectar(int registro){
			try{
		 	conn = new MySqlConnection("host="+this.dbhost+";port=" + this.dbport + ";user id="+this.dbuser+";password="+this.dbpasoteword+ ";database=formulacion");

		 	adap = new MySqlDataAdapter();
			ds = new System.Data.DataSet();
			
			if( registro >= 0){
		 		adap.SelectCommand = new MySqlCommand("SELECT * FROM aceptaciones WHERE AceptacionID="+ registro.ToString() + ";",conn);
		 		
			}
		 	else{
			 	adap.SelectCommand = new MySqlCommand("SELECT * FROM aceptaciones;",conn);
				}
			adap.Fill(ds,"Aceptaciones");
		 	
		 	return true;
			}catch(MySqlException ex){
				FM_Errores.MostrarError("AceptacionesForm","Error relacionado con base de datos",ex);
				return false;
			}catch(Exception e){
				FM_Errores.MostrarError("AceptacionesForm","Error general. No se puede cargar la informacin",e);
				return false;
			}
		 	
		}

		private void CargarComandoUpdate(){
			adap.UpdateCommand = new MySqlCommand("Update aceptaciones Set PersonalID = ?PersonalID, Fecha = ?Fecha, Contenido=?Contenido WHERE AceptacionID = ?AceptacionID",conn);
			
			parm = adap.UpdateCommand.Parameters.Add("?AceptacionID", MySqlDbType.Int32);
			parm.SourceColumn = "AceptacionID";
			parm.SourceVersion = DataRowVersion.Current;
			
			parm = adap.UpdateCommand.Parameters.Add("?PersonalID", MySqlDbType.Int32);
			parm.SourceColumn = "PersonalID";
			parm.SourceVersion = DataRowVersion.Current;
			
			parm = adap.UpdateCommand.Parameters.Add("?Fecha", MySqlDbType.VarChar, 45 );
			parm.SourceColumn = "Fecha";
			parm.SourceVersion = DataRowVersion.Current;
			
			parm = adap.UpdateCommand.Parameters.Add("?Contenido", MySqlDbType.Int32);
			parm.SourceColumn = "Contenido";
			parm.SourceVersion = DataRowVersion.Current;
			
		}
		
		private void CargarComandoDelete(){
			adap.DeleteCommand = new MySqlCommand("DELETE FROM aceptaciones WHERE AceptacionID = ?AceptacionID",conn);
			
			parm = adap.DeleteCommand.Parameters.Add("?AceptacionID", MySqlDbType.Int32);
			parm.SourceColumn = "AceptacionID";
			parm.SourceVersion = DataRowVersion.Original;
			
		}
		
		private void CargarComandoInsert(){
			adap.InsertCommand = new MySqlCommand("Insert into aceptaciones(AceptacionID, PersonalID, Fecha, Contenido) VALUES (?AceptacionID, ?PersonalID, ?Fecha, ?Contenido)",conn);
			
			parm = adap.InsertCommand.Parameters.Add("?AceptacionID", MySqlDbType.Int32);
			parm.SourceColumn = "AceptacionID";
			parm.SourceVersion = DataRowVersion.Current;
			
			parm = adap.InsertCommand.Parameters.Add("?PersonalID", MySqlDbType.Int32);
			parm.SourceColumn = "PersonalID";
			parm.SourceVersion = DataRowVersion.Current;
			
			parm = adap.InsertCommand.Parameters.Add("?Fecha", MySqlDbType.VarChar, 45 );
			parm.SourceColumn = "Fecha";
			parm.SourceVersion = DataRowVersion.Current;
			
			parm = adap.InsertCommand.Parameters.Add("?Contenido", MySqlDbType.Int32);
			parm.SourceColumn = "Contenido";
			parm.SourceVersion = DataRowVersion.Current;

		}

		
		#region Windows Forms Designer generated code
		/// <summary>
		/// This method is required for Windows Forms designer support.
		/// Do not change the method contents inside the source code editor. The Forms designer might
		/// not be able to load this method if it was changed manually.
		/// </summary>
		private void InitializeComponent() {
			this.lblFecha = new System.Windows.Forms.Label();
			this.txtPersonalID = new System.Windows.Forms.TextBox();
			this.chkContenido = new System.Windows.Forms.CheckBox();
			this.txtAceptacionID = new System.Windows.Forms.TextBox();
			this.lblAceptacionID = new System.Windows.Forms.Label();
			this.txtFecha = new System.Windows.Forms.TextBox();
			this.lblPersonalID = new System.Windows.Forms.Label();
			this.btnGuardar = new System.Windows.Forms.Button();
			this.lblContenido = new System.Windows.Forms.Label();
			this.lblPos = new System.Windows.Forms.Label();
			this.btnPersonal = new System.Windows.Forms.Button();
			this.SuspendLayout();
			// 
			// lblFecha
			// 
			this.lblFecha.Location = new System.Drawing.Point(8, 104);
			this.lblFecha.Name = "lblFecha";
			this.lblFecha.Size = new System.Drawing.Size(88, 16);
			this.lblFecha.TabIndex = 3;
			this.lblFecha.Text = "Fecha";
			// 
			// txtPersonalID
			// 
			this.txtPersonalID.Location = new System.Drawing.Point(96, 56);
			this.txtPersonalID.Name = "txtPersonalID";
			this.txtPersonalID.Size = new System.Drawing.Size(168, 20);
			this.txtPersonalID.TabIndex = 5;
			this.txtPersonalID.Text = "";
			// 
			// chkContenido
			// 
			this.chkContenido.Location = new System.Drawing.Point(96, 136);
			this.chkContenido.Name = "chkContenido";
			this.chkContenido.Size = new System.Drawing.Size(168, 16);
			this.chkContenido.TabIndex = 7;
			this.chkContenido.Text = "Aprobado";
			// 
			// txtAceptacionID
			// 
			this.txtAceptacionID.Location = new System.Drawing.Point(96, 16);
			this.txtAceptacionID.Name = "txtAceptacionID";
			this.txtAceptacionID.Size = new System.Drawing.Size(168, 20);
			this.txtAceptacionID.TabIndex = 0;
			this.txtAceptacionID.Text = "";
			// 
			// lblAceptacionID
			// 
			this.lblAceptacionID.Location = new System.Drawing.Point(8, 16);
			this.lblAceptacionID.Name = "lblAceptacionID";
			this.lblAceptacionID.Size = new System.Drawing.Size(88, 16);
			this.lblAceptacionID.TabIndex = 1;
			this.lblAceptacionID.Text = "Aceptacion ID";
			// 
			// txtFecha
			// 
			this.txtFecha.Location = new System.Drawing.Point(96, 96);
			this.txtFecha.Name = "txtFecha";
			this.txtFecha.Size = new System.Drawing.Size(168, 20);
			this.txtFecha.TabIndex = 6;
			this.txtFecha.Text = "";
			// 
			// lblPersonalID
			// 
			this.lblPersonalID.Location = new System.Drawing.Point(8, 64);
			this.lblPersonalID.Name = "lblPersonalID";
			this.lblPersonalID.Size = new System.Drawing.Size(88, 16);
			this.lblPersonalID.TabIndex = 2;
			this.lblPersonalID.Text = "Personal ID";
			// 
			// btnGuardar
			// 
			this.btnGuardar.Location = new System.Drawing.Point(120, 168);
			this.btnGuardar.Name = "btnGuardar";
			this.btnGuardar.Size = new System.Drawing.Size(240, 24);
			this.btnGuardar.TabIndex = 10;
			this.btnGuardar.Text = "Guardar";
			this.btnGuardar.Click += new System.EventHandler(this.BtnGuardarClick);
			// 
			// lblContenido
			// 
			this.lblContenido.Location = new System.Drawing.Point(8, 136);
			this.lblContenido.Name = "lblContenido";
			this.lblContenido.Size = new System.Drawing.Size(88, 16);
			this.lblContenido.TabIndex = 4;
			this.lblContenido.Text = "Contenido";
			// 
			// lblPos
			// 
			this.lblPos.Location = new System.Drawing.Point(8, 176);
			this.lblPos.Name = "lblPos";
			this.lblPos.Size = new System.Drawing.Size(96, 16);
			this.lblPos.TabIndex = 9;
			this.lblPos.Text = "0 de 0";
			this.lblPos.TextAlign = System.Drawing.ContentAlignment.MiddleCenter;
			// 
			// btnPersonal
			// 
			this.btnPersonal.Location = new System.Drawing.Point(272, 56);
			this.btnPersonal.Name = "btnPersonal";
			this.btnPersonal.Size = new System.Drawing.Size(88, 24);
			this.btnPersonal.TabIndex = 8;
			this.btnPersonal.Text = "Ver personal";
			this.btnPersonal.Click += new System.EventHandler(this.BtnPersonalClick);
			// 
			// AceptacionesForm
			// 
			this.AutoScaleBaseSize = new System.Drawing.Size(5, 13);
			this.ClientSize = new System.Drawing.Size(384, 197);
			this.Controls.Add(this.btnGuardar);
			this.Controls.Add(this.lblPos);
			this.Controls.Add(this.btnPersonal);
			this.Controls.Add(this.chkContenido);
			this.Controls.Add(this.txtFecha);
			this.Controls.Add(this.txtPersonalID);
			this.Controls.Add(this.lblContenido);
			this.Controls.Add(this.lblFecha);
			this.Controls.Add(this.lblPersonalID);
			this.Controls.Add(this.lblAceptacionID);
			this.Controls.Add(this.txtAceptacionID);
			this.FormBorderStyle = System.Windows.Forms.FormBorderStyle.FixedDialog;
			this.MaximizeBox = false;
			this.Name = "AceptacionesForm";
			this.Text = "AceptacionesForm";
			this.Load += new System.EventHandler(this.AceptacionesFormLoad);
			this.ResumeLayout(false);
		}
		#endregion
		void AceptacionesFormLoad(object sender, System.EventArgs e)
		{
			this.CargarConfiguracionDatabase();
			AlertaLocal.setConnectionParameters(this.dbhost ,this.dbport ,this.dbuser ,this.dbpasoteword ,"formulacion");
			if ( this.Conectar(this.RecPosition) )
			{
				this.RecPosition = 0;
				this.CargarComandoUpdate();
				this.CargarComandoInsert();
				this.CargarComandoDelete();
				this.RecCount = ds.Tables[0].Rows.Count;
				
			    MostrarPosicion();
			    this.CargarRegistro(this.RecPosition);
			}

		}
		
		void MostrarPosicion(){
			this.lblPos.Text = (this.RecPosition+1).ToString() + " de " + this.RecCount.ToString();
		}

		void CargarRegistro( int numero){
			if( numero >=0 && numero < ds.Tables[0].Rows.Count)
			{
				
				this.txtAceptacionID.Text = ds.Tables[0].Rows[numero]["AceptacionID"].ToString();
				this.txtPersonalID.Text = ds.Tables[0].Rows[numero]["PersonalID"].ToString();
				this.txtFecha.Text = ds.Tables[0].Rows[numero]["Fecha"].ToString();
				
				if( Convert.ToInt32 (ds.Tables[0].Rows[numero]["Contenido"]) != 0)
					this.chkContenido.Checked = true;
				else
					this.chkContenido.Checked = false;
			}
		}

		void GuardarRegistro(int numero){
			try{
			ds.Tables[0].Rows[numero].BeginEdit();
			ds.Tables[0].Rows[numero]["AceptacionID"] = this.txtAceptacionID.Text;
			ds.Tables[0].Rows[numero]["PersonalID"] = this.txtPersonalID.Text;
			ds.Tables[0].Rows[numero]["Fecha"] = this.txtFecha.Text;
			
			if( this.chkContenido.Checked)
				ds.Tables[0].Rows[numero]["Contenido"] = 1;
			else
				ds.Tables[0].Rows[numero]["Contenido"] = 0;
			
			ds.Tables[0].Rows[numero].EndEdit();
			}catch(Exception ex){
				FM_Errores.MostrarError("AceptacionesForm","No se puede modificar el registro",ex);
			}
			
		}

		
		void BtnGuardarClick(object sender, System.EventArgs e)
		{
			int l; // Nivel para guardar
			AuthLevel al = new AuthLevel();
			al.setConnectionParameters(this.dbhost ,this.dbport ,this.dbuser ,this.dbpasoteword ,"formulacion");

			l = al.get_level(83); // Modulo 8: Aceptaciones, accion 3: Modificar
			
			if(	this.currentlevel < l ){
				if( !AlertaLocal.registra_alerta("Error de seguridad al intentar modificar los datos de aceptaciones con el nivel de autorizacion " + this.currentlevel.ToString()))
				{
					FM_Errores.MostrarError("Error al registrar alerta de seguridad");
				}

				FM_Errores.MostrarError("Seguridad","Su nivel de autorizacin no le permite modificar los datos");
				return;
			}
			
			GuardarRegistro(this.RecPosition);
			GuardarModificaciones();

		}
	
		void GuardarModificaciones()
		{
			try
    			{
        		int Modificaciones= 0; 
        			Modificaciones += adap.Update(ds,"Aceptaciones");
        			ds.Clear();
        			adap.Fill(ds,"Aceptaciones");
        			this.RecPosition=0;
        			this.RecCount = ds.Tables[0].Rows.Count;
        			this.CargarRegistro (this.RecPosition );
        			this.MostrarPosicion();
        			FM_Errores.MostrarAviso("Actualizacion correcta","Actualizados "+Modificaciones+" registros");
        			
				}catch (Exception ex){
					FM_Errores.MostrarError("Actualizacion","Error actualizando datos",ex);
        	    }
			
		}


		
		void BtnPersonalClick(object sender, System.EventArgs e)
		{
			try{
			PersonalMiniVista pmv = new PersonalMiniVista(this.currentlevel, Convert.ToInt32 (ds.Tables[0].Rows[this.RecPosition]["PersonalID"]));
			pmv.ShowDialog();
			pmv.Dispose();
			}catch(Exception ex){
				FM_Errores.MostrarError("AceptacionesForm","No se puede mostrar la informacin de personal",ex);
			}
		}
		
	}
}
