/*
 * 
 * EnvasesForm
 * 
 * (C) Alvaro Cortes. 2007. alvarocortesc@gmail.com
 * 
 * 
 * Formulario de gestion de envases.
 * 
 */

using System;
using System.Drawing;
using System.Windows.Forms;
using System.Drawing.Printing;
using MySql.Data.MySqlClient;
using System.Data;


namespace FormulacionMagistral
{
	/// <summary>
	/// Description of EnvasesForm.
	/// </summary>
	public class EnvasesForm : System.Windows.Forms.Form
	{
		private System.Windows.Forms.Label lblObservaciones;
		private System.Windows.Forms.Label lblEnvaseID;
		private System.Windows.Forms.Button btnImprimir;
		private System.Windows.Forms.Button btnNuevo;
		private System.Windows.Forms.Label lblPrecio;
		private System.Windows.Forms.Label lblPos;
		private System.Windows.Forms.Button btnCerrar;
		private System.Windows.Forms.Button btnFirst;
		private System.Windows.Forms.Button btnNext;
		private System.Windows.Forms.Button btnPrev;
		private System.Windows.Forms.TextBox txtPrecio;
		private System.Windows.Forms.Label lblNombre;
		private System.Windows.Forms.Button btnBorrar;
		private System.Windows.Forms.TextBox txtNombre;
		private System.Windows.Forms.TextBox txtEnvaseID;
		private System.Windows.Forms.Button btnGuardar;
		private System.Windows.Forms.Button btnLast;
		private System.Windows.Forms.TextBox txtObservaciones;
		private System.Windows.Forms.Button btnImprimirListado;
		
		private MySqlConnection conn;
		private MySqlDataAdapter adap;  
		private System.Data.DataSet ds;
		private MySqlParameter parm;
		
	
		// Algunas variables para emular el CurrencyManager defectuoso de Mono
		private int RecCount;
		private int RecPosition;
				
		// Para cargar preferencias de la BD
		private Formulacion.PreferenciasDB DBPrefs;
		
		// Informacion para conexion BD
		private string dbhost;
		private string dbport;
		private string dbuser;
		private string dbpasoteword;
		
		// Para los datos de provincia y ao.
		
		private string Provincia;
		private string Annus;
		
		// Nivel de acceso
		private int currentlevel;
		private Alertas AlertaLocal; // Alertas

		
		/// <summary>
		/// Constructor
		/// </summary>
		/// <param name="provincia">Nombre de la pronvincia a cargar</param>
		/// <param name="annus">Ao a cargar</param>
		/// <param name="level">Nivel actual de acceso</param>
		public EnvasesForm(int level, string provincia, string annus)
		{
			//
			// The InitializeComponent() call is required for Windows Forms designer support.
			//
			InitializeComponent();

			this.currentlevel = level;
			
			this.Provincia = provincia;
			this.Annus = annus;
			
			DBPrefs = new Formulacion.PreferenciasDB();
			DBPrefs.AsignarNmbFichero("PrefDataBase.xml");
			
			//this.RecPosition = registro;
			AlertaLocal = new Alertas();

			
		}
		
		/// <summary>
		/// Obtiene el id del registro actual
		/// </summary>
		/// <returns>Devuelve un entero del ID del registro</returns>
		public int getcurrentid(){
			int n;
			try{
				n = Convert.ToInt32( this.txtEnvaseID.Text);
				return n;
			}catch(Exception ex){
				FM_Errores.MostrarError("GetCurrentID","No se puede obtener el ID actual",ex);
				return -1;
			}
		}

		
		
		/// <summary>
		/// Carga la configuracin de la base de datos en la vars
		/// de la clase
		/// </summary>
		void CargarConfiguracionDatabase(){
			string[] prf;
			if ( this.DBPrefs.LeerFichero() )
			{
				prf = this.DBPrefs.CargarPreferenciasDB();
				
				for( int i = 0; i < prf.Length; ++i)
				{
					switch(i){
						case 0: this.dbhost = prf[0]; break;
						case 1: this.dbport = prf[1]; break;
						case 3: this.dbuser = prf[2]; break;
						case 4: this.dbpasoteword = prf[3]; break;
					
					}
				}
				this.DBPrefs.CerrarEntrada();
			}
		}
		
		
		private bool Conectar(){
			try{
		 	conn = new MySqlConnection("host="+this.dbhost+";port=" + this.dbport + ";user id="+this.dbuser+";password="+this.dbpasoteword+ ";database=formulacion");

		 	adap = new MySqlDataAdapter();
			ds = new System.Data.DataSet();
			
			 	adap.SelectCommand = new MySqlCommand("SELECT * FROM envases_" + this.Provincia + "_" + this.Annus +";",conn);
			adap.Fill(ds,"Envases");
		 	
		 	return true;
			}catch(MySqlException ex){
				FM_Errores.MostrarError("EnvasesForm","Error relacionado con base de datos",ex);
				return false;
			}catch(Exception e){
				FM_Errores.MostrarError("EnvasesForm","Error general. No se puede cargar la informacion de envases",e);
				return false;
			}
		 	
		}

		private void CargarComandoUpdate(){
			adap.UpdateCommand = new MySqlCommand("Update envases_" + this.Provincia + "_" + this.Annus +" Set EnvaseID=?EnvaseID, Nombre = ?Nombre, Precio = ?Precio, Observaciones=?Observaciones WHERE EnvaseID = ?EnvaseIDA ",conn);
			
			parm = adap.UpdateCommand.Parameters.Add("?EnvaseIDA", MySqlDbType.Int32);
			parm.SourceColumn = "EnvaseID";
			parm.SourceVersion = DataRowVersion.Original;
							
			parm = adap.UpdateCommand.Parameters.Add("?EnvaseID", MySqlDbType.Int32);
			parm.SourceColumn = "EnvaseID";
			parm.SourceVersion = DataRowVersion.Current;
			
			parm = adap.UpdateCommand.Parameters.Add("?Nombre", MySqlDbType.VarChar, 150 );
			parm.SourceColumn = "Nombre";
			parm.SourceVersion = DataRowVersion.Current;

			parm = adap.UpdateCommand.Parameters.Add("?Precio", MySqlDbType.Float);
			parm.SourceColumn = "Precio";
			parm.SourceVersion = DataRowVersion.Current;

			parm = adap.UpdateCommand.Parameters.Add("?Observaciones", MySqlDbType.VarChar, 250);
			parm.SourceColumn = "Observaciones";
			parm.SourceVersion = DataRowVersion.Current;
			
			
		}
		
		private void CargarComandoDelete(){
			adap.DeleteCommand = new MySqlCommand("DELETE FROM envases_" + this.Provincia + "_" + this.Annus +" WHERE EnvaseID = ?EnvaseID",conn);
			
			parm = adap.DeleteCommand.Parameters.Add("?EnvaseID", MySqlDbType.Int32);
			parm.SourceColumn = "EnvaseID";
			parm.SourceVersion = DataRowVersion.Original;
			
		}
		
		private void CargarComandoInsert(){
			adap.InsertCommand = new MySqlCommand("Insert into envases_" + this.Provincia + "_" + this.Annus +"(EnvaseID, Nombre, Precio, Observaciones) VALUES (?EnvaseID, ?Nombre, ?Precio, ?Observaciones)",conn);
			
			parm = adap.InsertCommand.Parameters.Add("?EnvaseID", MySqlDbType.Int32);
			parm.SourceColumn = "EnvaseID";
			parm.SourceVersion = DataRowVersion.Current;
			
			parm = adap.InsertCommand.Parameters.Add("?Nombre", MySqlDbType.VarChar, 150 );
			parm.SourceColumn = "Nombre";
			parm.SourceVersion = DataRowVersion.Current;

			parm = adap.InsertCommand.Parameters.Add("?Precio", MySqlDbType.Float);
			parm.SourceColumn = "Precio";
			parm.SourceVersion = DataRowVersion.Current;

			parm = adap.InsertCommand.Parameters.Add("?Observaciones", MySqlDbType.VarChar, 250);
			parm.SourceColumn = "Observaciones";
			parm.SourceVersion = DataRowVersion.Current;

			
		}
		
		
		#region Windows Forms Designer generated code
		/// <summary>
		/// This method is required for Windows Forms designer support.
		/// Do not change the method contents inside the source code editor. The Forms designer might
		/// not be able to load this method if it was changed manually.
		/// </summary>
		private void InitializeComponent() {
			this.btnImprimirListado = new System.Windows.Forms.Button();
			this.txtObservaciones = new System.Windows.Forms.TextBox();
			this.btnLast = new System.Windows.Forms.Button();
			this.btnGuardar = new System.Windows.Forms.Button();
			this.txtEnvaseID = new System.Windows.Forms.TextBox();
			this.txtNombre = new System.Windows.Forms.TextBox();
			this.btnBorrar = new System.Windows.Forms.Button();
			this.lblNombre = new System.Windows.Forms.Label();
			this.txtPrecio = new System.Windows.Forms.TextBox();
			this.btnPrev = new System.Windows.Forms.Button();
			this.btnNext = new System.Windows.Forms.Button();
			this.btnFirst = new System.Windows.Forms.Button();
			this.btnCerrar = new System.Windows.Forms.Button();
			this.lblPos = new System.Windows.Forms.Label();
			this.lblPrecio = new System.Windows.Forms.Label();
			this.btnNuevo = new System.Windows.Forms.Button();
			this.btnImprimir = new System.Windows.Forms.Button();
			this.lblEnvaseID = new System.Windows.Forms.Label();
			this.lblObservaciones = new System.Windows.Forms.Label();
			this.SuspendLayout();
			// 
			// btnImprimirListado
			// 
			this.btnImprimirListado.Location = new System.Drawing.Point(408, 136);
			this.btnImprimirListado.Name = "btnImprimirListado";
			this.btnImprimirListado.Size = new System.Drawing.Size(104, 24);
			this.btnImprimirListado.TabIndex = 45;
			this.btnImprimirListado.Text = "Imprimir Listado";
			this.btnImprimirListado.Click += new System.EventHandler(this.BtnImprimirListadoClick);
			// 
			// txtObservaciones
			// 
			this.txtObservaciones.Location = new System.Drawing.Point(112, 104);
			this.txtObservaciones.Multiline = true;
			this.txtObservaciones.Name = "txtObservaciones";
			this.txtObservaciones.ScrollBars = System.Windows.Forms.ScrollBars.Both;
			this.txtObservaciones.Size = new System.Drawing.Size(272, 56);
			this.txtObservaciones.TabIndex = 52;
			this.txtObservaciones.Text = "";
			// 
			// btnLast
			// 
			this.btnLast.Location = new System.Drawing.Point(320, 184);
			this.btnLast.Name = "btnLast";
			this.btnLast.Size = new System.Drawing.Size(32, 24);
			this.btnLast.TabIndex = 49;
			this.btnLast.Text = "->|";
			this.btnLast.Click += new System.EventHandler(this.BtnLastClick);
			// 
			// btnGuardar
			// 
			this.btnGuardar.Location = new System.Drawing.Point(408, 72);
			this.btnGuardar.Name = "btnGuardar";
			this.btnGuardar.Size = new System.Drawing.Size(104, 24);
			this.btnGuardar.TabIndex = 41;
			this.btnGuardar.Text = "Guardar";
			this.btnGuardar.Click += new System.EventHandler(this.BtnGuardarClick);
			// 
			// txtEnvaseID
			// 
			this.txtEnvaseID.Location = new System.Drawing.Point(112, 8);
			this.txtEnvaseID.Name = "txtEnvaseID";
			this.txtEnvaseID.Size = new System.Drawing.Size(272, 20);
			this.txtEnvaseID.TabIndex = 34;
			this.txtEnvaseID.Text = "";
			// 
			// txtNombre
			// 
			this.txtNombre.Location = new System.Drawing.Point(112, 40);
			this.txtNombre.Name = "txtNombre";
			this.txtNombre.Size = new System.Drawing.Size(272, 20);
			this.txtNombre.TabIndex = 35;
			this.txtNombre.Text = "";
			// 
			// btnBorrar
			// 
			this.btnBorrar.Location = new System.Drawing.Point(408, 40);
			this.btnBorrar.Name = "btnBorrar";
			this.btnBorrar.Size = new System.Drawing.Size(104, 24);
			this.btnBorrar.TabIndex = 42;
			this.btnBorrar.Text = "Borrar";
			this.btnBorrar.Click += new System.EventHandler(this.BtnBorrarClick);
			// 
			// lblNombre
			// 
			this.lblNombre.Location = new System.Drawing.Point(16, 40);
			this.lblNombre.Name = "lblNombre";
			this.lblNombre.Size = new System.Drawing.Size(72, 16);
			this.lblNombre.TabIndex = 38;
			this.lblNombre.Text = "Nombre";
			// 
			// txtPrecio
			// 
			this.txtPrecio.Location = new System.Drawing.Point(112, 72);
			this.txtPrecio.Name = "txtPrecio";
			this.txtPrecio.Size = new System.Drawing.Size(272, 20);
			this.txtPrecio.TabIndex = 36;
			this.txtPrecio.Text = "";
			// 
			// btnPrev
			// 
			this.btnPrev.Location = new System.Drawing.Point(120, 184);
			this.btnPrev.Name = "btnPrev";
			this.btnPrev.Size = new System.Drawing.Size(32, 24);
			this.btnPrev.TabIndex = 47;
			this.btnPrev.Text = "<-";
			this.btnPrev.Click += new System.EventHandler(this.BtnPrevClick);
			// 
			// btnNext
			// 
			this.btnNext.Location = new System.Drawing.Point(288, 184);
			this.btnNext.Name = "btnNext";
			this.btnNext.Size = new System.Drawing.Size(32, 24);
			this.btnNext.TabIndex = 48;
			this.btnNext.Text = "->";
			this.btnNext.Click += new System.EventHandler(this.BtnNextClick);
			// 
			// btnFirst
			// 
			this.btnFirst.Location = new System.Drawing.Point(88, 184);
			this.btnFirst.Name = "btnFirst";
			this.btnFirst.Size = new System.Drawing.Size(32, 24);
			this.btnFirst.TabIndex = 46;
			this.btnFirst.Text = "|<-";
			this.btnFirst.Click += new System.EventHandler(this.BtnFirstClick);
			// 
			// btnCerrar
			// 
			this.btnCerrar.Location = new System.Drawing.Point(408, 168);
			this.btnCerrar.Name = "btnCerrar";
			this.btnCerrar.Size = new System.Drawing.Size(104, 24);
			this.btnCerrar.TabIndex = 43;
			this.btnCerrar.Text = "Cerrar";
			this.btnCerrar.Click += new System.EventHandler(this.BtnCerrarClick);
			// 
			// lblPos
			// 
			this.lblPos.Location = new System.Drawing.Point(160, 184);
			this.lblPos.Name = "lblPos";
			this.lblPos.Size = new System.Drawing.Size(128, 24);
			this.lblPos.TabIndex = 50;
			this.lblPos.Text = "0 de 0";
			this.lblPos.TextAlign = System.Drawing.ContentAlignment.MiddleCenter;
			// 
			// lblPrecio
			// 
			this.lblPrecio.Location = new System.Drawing.Point(16, 72);
			this.lblPrecio.Name = "lblPrecio";
			this.lblPrecio.Size = new System.Drawing.Size(88, 24);
			this.lblPrecio.TabIndex = 39;
			this.lblPrecio.Text = "Precio";
			// 
			// btnNuevo
			// 
			this.btnNuevo.Location = new System.Drawing.Point(408, 8);
			this.btnNuevo.Name = "btnNuevo";
			this.btnNuevo.Size = new System.Drawing.Size(104, 24);
			this.btnNuevo.TabIndex = 40;
			this.btnNuevo.Text = "Nuevo";
			this.btnNuevo.Click += new System.EventHandler(this.BtnNuevoClick);
			// 
			// btnImprimir
			// 
			this.btnImprimir.Location = new System.Drawing.Point(408, 104);
			this.btnImprimir.Name = "btnImprimir";
			this.btnImprimir.Size = new System.Drawing.Size(104, 24);
			this.btnImprimir.TabIndex = 44;
			this.btnImprimir.Text = "Imprimir Ficha";
			this.btnImprimir.Click += new System.EventHandler(this.BtnImprimirClick);
			// 
			// lblEnvaseID
			// 
			this.lblEnvaseID.Location = new System.Drawing.Point(16, 16);
			this.lblEnvaseID.Name = "lblEnvaseID";
			this.lblEnvaseID.Size = new System.Drawing.Size(80, 16);
			this.lblEnvaseID.TabIndex = 37;
			this.lblEnvaseID.Text = "Envase ID";
			// 
			// lblObservaciones
			// 
			this.lblObservaciones.Location = new System.Drawing.Point(16, 104);
			this.lblObservaciones.Name = "lblObservaciones";
			this.lblObservaciones.Size = new System.Drawing.Size(80, 24);
			this.lblObservaciones.TabIndex = 51;
			this.lblObservaciones.Text = "Observaciones";
			// 
			// EnvasesForm
			// 
			this.AutoScaleBaseSize = new System.Drawing.Size(5, 13);
			this.ClientSize = new System.Drawing.Size(528, 221);
			this.Controls.Add(this.txtObservaciones);
			this.Controls.Add(this.lblObservaciones);
			this.Controls.Add(this.lblPos);
			this.Controls.Add(this.btnLast);
			this.Controls.Add(this.btnNext);
			this.Controls.Add(this.btnPrev);
			this.Controls.Add(this.btnFirst);
			this.Controls.Add(this.btnImprimirListado);
			this.Controls.Add(this.btnImprimir);
			this.Controls.Add(this.btnCerrar);
			this.Controls.Add(this.btnBorrar);
			this.Controls.Add(this.btnGuardar);
			this.Controls.Add(this.btnNuevo);
			this.Controls.Add(this.lblPrecio);
			this.Controls.Add(this.lblNombre);
			this.Controls.Add(this.lblEnvaseID);
			this.Controls.Add(this.txtPrecio);
			this.Controls.Add(this.txtNombre);
			this.Controls.Add(this.txtEnvaseID);
			this.Name = "EnvasesForm";
			this.Text = "EnvasesForm";
			this.Load += new System.EventHandler(this.EnvasesFormLoad);
			this.ResumeLayout(false);
		}
		#endregion
		void EnvasesFormLoad(object sender, System.EventArgs e)
		{
			this.CargarConfiguracionDatabase();
			AlertaLocal.setConnectionParameters(this.dbhost ,this.dbport ,this.dbuser ,this.dbpasoteword ,"formulacion");
			if ( this.Conectar() )
			{
				this.RecPosition = 0;
				this.CargarComandoUpdate();
				this.CargarComandoInsert();
				this.CargarComandoDelete();
				this.RecCount = ds.Tables[0].Rows.Count;
				
			    MostrarPosicion();
			    this.CargarRegistro(this.RecPosition);
			}
			
		}
		
		void MostrarPosicion(){
			this.lblPos.Text = (this.RecPosition+1).ToString() + " de " + this.RecCount.ToString();
		}

		void CargarRegistro( int numero){
			
			if( numero >=0 && numero < ds.Tables[0].Rows.Count)
			{
				this.txtEnvaseID.Text = ds.Tables[0].Rows[numero]["EnvaseID"].ToString();
				this.txtNombre.Text = ds.Tables[0].Rows[numero]["Nombre"].ToString();
				this.txtPrecio.Text = ds.Tables[0].Rows[numero]["Precio"].ToString();
				this.txtObservaciones.Text = ds.Tables[0].Rows[numero]["Observaciones"].ToString();
			}
		}

		
		void BtnNextClick(object sender, System.EventArgs e)
		{
			if( this.RecPosition < this.RecCount-1)
			this.RecPosition++;
			this.MostrarPosicion();
			this.CargarRegistro(this.RecPosition);
		}
		
		void BtnPrevClick(object sender, System.EventArgs e)
		{
			if( this.RecPosition > 0)
			this.RecPosition--;
			this.MostrarPosicion();
			this.CargarRegistro(this.RecPosition);
		}
		
		
		void BtnLastClick(object sender, System.EventArgs e)
		{
			this.RecPosition = this.RecCount-1;
			this.MostrarPosicion();
			this.CargarRegistro(this.RecPosition);
		}
		
		void BtnFirstClick(object sender, System.EventArgs e)
		{
			this.RecPosition = 0;
			this.MostrarPosicion();
			this.CargarRegistro(this.RecPosition);			
		}
		
		void BtnCerrarClick(object sender, System.EventArgs e)
		{
			this.Close();
		}
		
		void BtnNuevoClick(object sender, System.EventArgs e)
		{
			int l; // Nivel para nuevo
			AuthLevel al = new AuthLevel();
			al.setConnectionParameters(this.dbhost ,this.dbport ,this.dbuser ,this.dbpasoteword ,"formulacion");

			l = al.get_level(102); // Modulo 10: Envases, accion 2:Nuevo
			
			if(	this.currentlevel < l ){
				if( !AlertaLocal.registra_alerta("Error de seguridad al intentar aadir datos de envases con el nivel de autorizacion " + this.currentlevel.ToString()))
				{
					FM_Errores.MostrarError("Error al registrar alerta de seguridad");
				}

				FM_Errores.MostrarError("Seguridad","Su nivel de autorizacin no le permite aadir datos");
				return;
			}

			ds.Tables[0].Rows.Add(new Object[ds.Tables[0].Columns.Count]);
			this.RecCount = ds.Tables[0].Rows.Count;
			this.RecPosition = this.RecCount-1;
			
			this.MostrarPosicion();
			this.CargarRegistro(this.RecPosition);

		}
		
		void Borrado(object sender, System.Data.DataRowChangeEventArgs e)
		{
			DataRow[] pendientes;
			try{
			pendientes = ds.Tables[0].Select("", "", DataViewRowState.Deleted);
			FM_Errores.MostrarAviso("Borrado","Se han borrado " + adap.Update(pendientes).ToString() + " registros");
					ds.Clear();
        			adap.Fill(ds,"Envases");
        			this.RecPosition=0;
        			this.RecCount = ds.Tables[0].Rows.Count;
        			this.CargarRegistro (this.RecPosition );
        			this.MostrarPosicion();

			}catch(Exception ex){
				FM_Errores.MostrarError("EnvasesForm","No se puede borrar",ex);
			}
		}

		
		void BtnBorrarClick(object sender, System.EventArgs e)
		{
			int l; // Nivel para borrar
			AuthLevel al = new AuthLevel();
			al.setConnectionParameters(this.dbhost ,this.dbport ,this.dbuser ,this.dbpasoteword ,"formulacion");

			l = al.get_level(101); // Modulo 10: Envases, accion 3: Borrar
			
			if(	this.currentlevel < l ){
				if( !AlertaLocal.registra_alerta("Error de seguridad al intentar borrar los datos de envases con el nivel de autorizacion " + this.currentlevel.ToString()))
				{
					FM_Errores.MostrarError("Error al registrar alerta de seguridad");
				}

				FM_Errores.MostrarError("Seguridad","Su nivel de autorizacin no le permite borrar datos");
				return;
			}
			
			if (MessageBox.Show("Esta seguro?", "Confirmacin", MessageBoxButtons.YesNo, MessageBoxIcon.Question) == DialogResult.No)
				return;
			
			try{
			ds.Tables[0].RowDeleted += new System.Data.DataRowChangeEventHandler(Borrado);
			ds.Tables["Envases"].Rows.RemoveAt( this.RecPosition);
			}catch(Exception ex){
				FM_Errores.MostrarError("EnvasesForm","No se puede borrar el envase",ex);
			}
		}
		
		
		void GuardarRegistro(int numero){
			try{
			ds.Tables[0].Rows[numero].BeginEdit();
			ds.Tables[0].Rows[numero][0] = this.txtEnvaseID.Text;
			ds.Tables[0].Rows[numero][1] = this.txtNombre.Text;
			ds.Tables[0].Rows[numero][2] = this.txtPrecio.Text;
			ds.Tables[0].Rows[numero][3] = this.txtObservaciones.Text;
			ds.Tables[0].Rows[numero].EndEdit();
			}catch(Exception ex){
				FM_Errores.MostrarError("EnvasesForm","No se puede modificar el registro",ex);
			}
			
		}

		void GuardarModificaciones()
		{
			try
    			{
        		int Modificaciones= 0; 
				DataRow[] pendientes;

					pendientes = ds.Tables[0].Select("", "", DataViewRowState.Deleted);
					Modificaciones = adap.Update(pendientes);
        		
        			Modificaciones += adap.Update(ds,"Envases");
        			ds.Clear();
        			adap.Fill(ds,"Envases");
        			this.RecPosition=0;
        			this.RecCount = ds.Tables[0].Rows.Count;
        			this.CargarRegistro (this.RecPosition );
        			this.MostrarPosicion();
        			FM_Errores.MostrarAviso("Actualizacion correcta","Actualizados "+Modificaciones+" registros");
        			
				}catch (Exception ex){
					FM_Errores.MostrarError("Actualizacion","Error actualizando datos",ex);
        	    }
			
		}

		
		void BtnGuardarClick(object sender, System.EventArgs e)
		{
			int l; // Nivel para guardar
			AuthLevel al = new AuthLevel();
			al.setConnectionParameters(this.dbhost ,this.dbport ,this.dbuser ,this.dbpasoteword ,"formulacion");

			l = al.get_level(103); // Modulo 10: Envases, accion 3: Modificar
			
			if(	this.currentlevel < l ){
				if( !AlertaLocal.registra_alerta("Error de seguridad al intentar modificar los datos de envases con el nivel de autorizacion " + this.currentlevel.ToString()))
				{
					FM_Errores.MostrarError("Error al registrar alerta de seguridad");
				}

				FM_Errores.MostrarError("Seguridad","Su nivel de autorizacin no le permite modificar los datos");
				return;
			}
			
			GuardarRegistro(this.RecPosition);
			GuardarModificaciones();
		}
		
		private void ImprimirListado(int from, int dest)
		{
			try{
			Formulacion.Impresiones docMaterial = new Formulacion.Impresiones();
			PrintPreviewDialog prevDialog = new PrintPreviewDialog();
			PrintDialog prdialog = new PrintDialog();
			
			docMaterial.ImprimirCabezera();
			docMaterial.NuevoTexto("Listado de Envases.");
			
			object[] a;
			
			for(int i=from ; i<dest; ++i)
			{
			a = ds.Tables[0].Rows[i].ItemArray;
			string observaciones;
			docMaterial.NuevaLinea();
			docMaterial.NuevoTexto("EnvaseID: " + a[0].ToString());
			docMaterial.NuevoTexto("Nombre: " + a[1].ToString());
			docMaterial.NuevoTexto("Precio: " + a[2].ToString());
			observaciones = a[3].ToString();
			observaciones.Replace('\n','.');
			docMaterial.NuevoTexto("Observaciones: " + observaciones);
			docMaterial.NuevoTexto("");
			}
			
			prevDialog.Document = docMaterial;
			prdialog.Document = docMaterial;
			
			docMaterial.PrintPage += new PrintPageEventHandler(docMaterial.ImprimirElementos);
			docMaterial.BeginPrint += new PrintEventHandler (docMaterial.Reajustar);
			
			// TODO. Esto esta por ser configurable en fichero XML o DB
			// docMaterial.MuestraPrefsPagina();
			
			
			// TODO. Esto tambien deberia ser configurable
			prevDialog.Text = "Previsualizacion del listado de envases";
			prevDialog.ShowDialog();
			
			if (prdialog.ShowDialog()== DialogResult.OK)
			{
				docMaterial.Print();
			}

			
			}catch(Exception ex){
				FM_Errores.MostrarError("Impresion","No se puede imprimir el listado de envases",ex);
			}

		}

		
		
		void BtnImprimirListadoClick(object sender, System.EventArgs e)
		{
			this.ImprimirListado(0,ds.Tables[0].Rows.Count);
		}
		
		void BtnImprimirClick(object sender, System.EventArgs e)
		{
			this.ImprimirListado(this.RecPosition,this.RecPosition+1);
		}
		
		
	}
}
