/*
 * 
 * PacientesTelefono
 * 
 * (C) Alvaro Cortes. 2007. alvarocortesc@gmail.com
 * 
 * SubFormulario para los telefonos de contacto de los proveedores
 * 
 */

using System;
using System.Drawing;
using System.Windows.Forms;
using System.Drawing.Printing;
using MySql.Data.MySqlClient;
using System.Data;

namespace FormulacionMagistral
{
	/// <summary>
	/// Description of PacientesTelefono.
	/// </summary>
	public class PacientesTelefono : System.Windows.Forms.Form
	{
		private System.Windows.Forms.Button btnGuardar;
		private System.Windows.Forms.TextBox txtTelefono;
		private System.Windows.Forms.Button btnImprimir;
		private System.Windows.Forms.Button btnNuevo;
		private System.Windows.Forms.Button btnFirst;
		private System.Windows.Forms.Label lblPos;
		private System.Windows.Forms.Button btnCerrar;
		private System.Windows.Forms.Label lblContacto;
		private System.Windows.Forms.Button btnPrev;
		private System.Windows.Forms.Label lblPacienteID;
		private System.Windows.Forms.Label lblTelefono;
		private System.Windows.Forms.TextBox txtPacienteID;
		private System.Windows.Forms.Button btnImprimirListado;
		private System.Windows.Forms.Button btnBorrar;
		private System.Windows.Forms.Button btnNext;
		private System.Windows.Forms.Button btnLast;
		private System.Windows.Forms.TextBox txtContacto;
		
		
		
		private MySqlConnection conn;
		private MySqlDataAdapter adap;  
		private System.Data.DataSet ds;
		private MySqlParameter parm;
		
	
		// Algunas variables para emular el CurrencyManager defectuoso de Mono
		private int RecCount;
		private int RecPosition;
				
		// Para cargar preferencias de la BD
		private Formulacion.PreferenciasDB DBPrefs;
		
		// Informacion para conexion BD
		private string dbhost;
		private string dbport;
		private string dbuser;
		private string dbpasoteword;
		
		
		
		// Nivel de acceso
		private int currentlevel;
		private Alertas AlertaLocal; // Alertas

		/// <summary>
		/// Constructor de PacienteTelefono
		/// </summary>
		/// <param name="level">Nivel de acceso</param>
		/// <param name="registro">ID del paciente. Menor de 0 carga todos</param>
		public PacientesTelefono(int level, int registro)
		{
			//
			// The InitializeComponent() call is required for Windows Forms designer support.
			//
			InitializeComponent();
			
			this.currentlevel = level;
			
			DBPrefs = new Formulacion.PreferenciasDB();
			DBPrefs.AsignarNmbFichero("PrefDataBase.xml");
			
			this.RecPosition = registro;
			AlertaLocal = new Alertas();

			}
		
		/// <summary>
		/// Carga la configuracin de la base de datos en la vars
		/// de la clase
		/// </summary>
		void CargarConfiguracionDatabase(){
			string[] prf;
			if ( this.DBPrefs.LeerFichero() )
			{
				prf = this.DBPrefs.CargarPreferenciasDB();
				
				for( int i = 0; i < prf.Length; ++i)
				{
					switch(i){
						case 0: this.dbhost = prf[0]; break;
						case 1: this.dbport = prf[1]; break;
						case 3: this.dbuser = prf[2]; break;
						case 4: this.dbpasoteword = prf[3]; break;
					
					}
				}
				this.DBPrefs.CerrarEntrada();
			}
		}
		
		
		private bool Conectar(int registro){
			try{
		 	conn = new MySqlConnection("host="+this.dbhost+";port=" + this.dbport + ";user id="+this.dbuser+";password="+this.dbpasoteword+ ";database=formulacion");

		 	adap = new MySqlDataAdapter();
			ds = new System.Data.DataSet();
			
			if( registro >= 0){
		 		adap.SelectCommand = new MySqlCommand("SELECT * FROM pacientestelefono WHERE PacienteID="+ registro.ToString() + ";",conn);
		 		
			}
		 	else{
			 	adap.SelectCommand = new MySqlCommand("SELECT * FROM proveedorestelefono;",conn);
				}
			adap.Fill(ds,"PacientesTelefono");
		 	
		 	return true;
			}catch(MySqlException ex){
				FM_Errores.MostrarError("PacientesTelefonoForm","Error relacionado con base de datos",ex);
				return false;
			}catch(Exception e){
				FM_Errores.MostrarError("PacientesTelefonoForm","Error general. No se puede cargar la informacion de telefonos de pacientes",e);
				return false;
			}
		 	
		}

		private void CargarComandoUpdate(){
			adap.UpdateCommand = new MySqlCommand("Update pacientestelefono Set Telefono = ?Telefono, Contacto = ?Contacto WHERE PacienteID = ?PacienteID AND Telefono = ?TelefonoA ",conn);
			
			parm = adap.UpdateCommand.Parameters.Add("?PacienteID", MySqlDbType.Int32);
			parm.SourceColumn = "PacienteID";
			parm.SourceVersion = DataRowVersion.Original;
							
			parm = adap.UpdateCommand.Parameters.Add("?Telefono", MySqlDbType.VarChar, 45 );
			parm.SourceColumn = "Telefono";
			parm.SourceVersion = DataRowVersion.Current;
			
			parm = adap.UpdateCommand.Parameters.Add("?TelefonoA", MySqlDbType.VarChar, 45 );
			parm.SourceColumn = "Telefono";
			parm.SourceVersion = DataRowVersion.Original;

			parm = adap.UpdateCommand.Parameters.Add("?Contacto", MySqlDbType.VarChar, 100 );
			parm.SourceColumn = "Contacto";
			parm.SourceVersion = DataRowVersion.Current;
			
		}
		
		private void CargarComandoDelete(){
			adap.DeleteCommand = new MySqlCommand("DELETE FROM pacientestelefono WHERE Telefono = ?Telefono",conn);
			
			parm = adap.DeleteCommand.Parameters.Add("?Telefono", MySqlDbType.VarChar, 45);
			parm.SourceColumn = "Telefono";
			parm.SourceVersion = DataRowVersion.Original;
			
		}
		
		private void CargarComandoInsert(){
			adap.InsertCommand = new MySqlCommand("Insert into pacientestelefono(PacienteID, Telefono, Contacto) VALUES (?PacienteID, ?Telefono, ?Contacto)",conn);
			
			parm = adap.InsertCommand.Parameters.Add("?PacienteID", MySqlDbType.Int32);
			parm.SourceColumn = "PacienteID";
			parm.SourceVersion = DataRowVersion.Current;
			
			parm = adap.InsertCommand.Parameters.Add("?Telefono", MySqlDbType.VarChar, 45 );
			parm.SourceColumn = "Telefono";
			parm.SourceVersion = DataRowVersion.Current;
			
			parm = adap.InsertCommand.Parameters.Add("?Contacto", MySqlDbType.VarChar, 100 );
			parm.SourceColumn = "Contacto";
			parm.SourceVersion = DataRowVersion.Current;
		}

		
		
		
		#region Windows Forms Designer generated code
		/// <summary>
		/// This method is required for Windows Forms designer support.
		/// Do not change the method contents inside the source code editor. The Forms designer might
		/// not be able to load this method if it was changed manually.
		/// </summary>
		private void InitializeComponent() {
			this.txtContacto = new System.Windows.Forms.TextBox();
			this.btnLast = new System.Windows.Forms.Button();
			this.btnNext = new System.Windows.Forms.Button();
			this.btnBorrar = new System.Windows.Forms.Button();
			this.btnImprimirListado = new System.Windows.Forms.Button();
			this.txtPacienteID = new System.Windows.Forms.TextBox();
			this.lblTelefono = new System.Windows.Forms.Label();
			this.lblPacienteID = new System.Windows.Forms.Label();
			this.btnPrev = new System.Windows.Forms.Button();
			this.lblContacto = new System.Windows.Forms.Label();
			this.btnCerrar = new System.Windows.Forms.Button();
			this.lblPos = new System.Windows.Forms.Label();
			this.btnFirst = new System.Windows.Forms.Button();
			this.btnNuevo = new System.Windows.Forms.Button();
			this.btnImprimir = new System.Windows.Forms.Button();
			this.txtTelefono = new System.Windows.Forms.TextBox();
			this.btnGuardar = new System.Windows.Forms.Button();
			this.SuspendLayout();
			// 
			// txtContacto
			// 
			this.txtContacto.Location = new System.Drawing.Point(104, 72);
			this.txtContacto.Name = "txtContacto";
			this.txtContacto.Size = new System.Drawing.Size(272, 20);
			this.txtContacto.TabIndex = 19;
			this.txtContacto.Text = "";
			// 
			// btnLast
			// 
			this.btnLast.Location = new System.Drawing.Point(120, 104);
			this.btnLast.Name = "btnLast";
			this.btnLast.Size = new System.Drawing.Size(32, 24);
			this.btnLast.TabIndex = 32;
			this.btnLast.Text = "->|";
			this.btnLast.Click += new System.EventHandler(this.BtnLastClick);
			// 
			// btnNext
			// 
			this.btnNext.Location = new System.Drawing.Point(88, 104);
			this.btnNext.Name = "btnNext";
			this.btnNext.Size = new System.Drawing.Size(32, 24);
			this.btnNext.TabIndex = 31;
			this.btnNext.Text = "->";
			this.btnNext.Click += new System.EventHandler(this.BtnNextClick);
			// 
			// btnBorrar
			// 
			this.btnBorrar.Location = new System.Drawing.Point(400, 40);
			this.btnBorrar.Name = "btnBorrar";
			this.btnBorrar.Size = new System.Drawing.Size(104, 24);
			this.btnBorrar.TabIndex = 25;
			this.btnBorrar.Text = "Borrar";
			this.btnBorrar.Click += new System.EventHandler(this.BtnBorrarClick);
			// 
			// btnImprimirListado
			// 
			this.btnImprimirListado.Location = new System.Drawing.Point(176, 104);
			this.btnImprimirListado.Name = "btnImprimirListado";
			this.btnImprimirListado.Size = new System.Drawing.Size(104, 24);
			this.btnImprimirListado.TabIndex = 28;
			this.btnImprimirListado.Text = "Imprimir Listado";
			this.btnImprimirListado.Click += new System.EventHandler(this.BtnImprimirListadoClick);
			// 
			// txtPacienteID
			// 
			this.txtPacienteID.Location = new System.Drawing.Point(104, 8);
			this.txtPacienteID.Name = "txtPacienteID";
			this.txtPacienteID.Size = new System.Drawing.Size(272, 20);
			this.txtPacienteID.TabIndex = 17;
			this.txtPacienteID.Text = "";
			// 
			// lblTelefono
			// 
			this.lblTelefono.Location = new System.Drawing.Point(8, 40);
			this.lblTelefono.Name = "lblTelefono";
			this.lblTelefono.Size = new System.Drawing.Size(72, 16);
			this.lblTelefono.TabIndex = 21;
			this.lblTelefono.Text = "Telefono";
			// 
			// lblPacienteID
			// 
			this.lblPacienteID.Location = new System.Drawing.Point(8, 16);
			this.lblPacienteID.Name = "lblPacienteID";
			this.lblPacienteID.Size = new System.Drawing.Size(80, 16);
			this.lblPacienteID.TabIndex = 20;
			this.lblPacienteID.Text = "Paciente ID";
			// 
			// btnPrev
			// 
			this.btnPrev.Location = new System.Drawing.Point(56, 104);
			this.btnPrev.Name = "btnPrev";
			this.btnPrev.Size = new System.Drawing.Size(32, 24);
			this.btnPrev.TabIndex = 30;
			this.btnPrev.Text = "<-";
			this.btnPrev.Click += new System.EventHandler(this.BtnPrevClick);
			// 
			// lblContacto
			// 
			this.lblContacto.Location = new System.Drawing.Point(8, 72);
			this.lblContacto.Name = "lblContacto";
			this.lblContacto.Size = new System.Drawing.Size(88, 24);
			this.lblContacto.TabIndex = 22;
			this.lblContacto.Text = "Contacto";
			// 
			// btnCerrar
			// 
			this.btnCerrar.Location = new System.Drawing.Point(288, 104);
			this.btnCerrar.Name = "btnCerrar";
			this.btnCerrar.Size = new System.Drawing.Size(104, 24);
			this.btnCerrar.TabIndex = 26;
			this.btnCerrar.Text = "Cerrar";
			this.btnCerrar.Click += new System.EventHandler(this.BtnCerrarClick);
			// 
			// lblPos
			// 
			this.lblPos.Location = new System.Drawing.Point(24, 128);
			this.lblPos.Name = "lblPos";
			this.lblPos.Size = new System.Drawing.Size(128, 24);
			this.lblPos.TabIndex = 33;
			this.lblPos.Text = "0 de 0";
			this.lblPos.TextAlign = System.Drawing.ContentAlignment.MiddleCenter;
			// 
			// btnFirst
			// 
			this.btnFirst.Location = new System.Drawing.Point(24, 104);
			this.btnFirst.Name = "btnFirst";
			this.btnFirst.Size = new System.Drawing.Size(32, 24);
			this.btnFirst.TabIndex = 29;
			this.btnFirst.Text = "|<-";
			this.btnFirst.Click += new System.EventHandler(this.BtnFirstClick);
			// 
			// btnNuevo
			// 
			this.btnNuevo.Location = new System.Drawing.Point(400, 8);
			this.btnNuevo.Name = "btnNuevo";
			this.btnNuevo.Size = new System.Drawing.Size(104, 24);
			this.btnNuevo.TabIndex = 23;
			this.btnNuevo.Text = "Nuevo";
			this.btnNuevo.Click += new System.EventHandler(this.BtnNuevoClick);
			// 
			// btnImprimir
			// 
			this.btnImprimir.Location = new System.Drawing.Point(400, 104);
			this.btnImprimir.Name = "btnImprimir";
			this.btnImprimir.Size = new System.Drawing.Size(104, 24);
			this.btnImprimir.TabIndex = 27;
			this.btnImprimir.Text = "Imprimir Ficha";
			this.btnImprimir.Click += new System.EventHandler(this.BtnImprimirClick);
			// 
			// txtTelefono
			// 
			this.txtTelefono.Location = new System.Drawing.Point(104, 40);
			this.txtTelefono.Name = "txtTelefono";
			this.txtTelefono.Size = new System.Drawing.Size(272, 20);
			this.txtTelefono.TabIndex = 18;
			this.txtTelefono.Text = "";
			// 
			// btnGuardar
			// 
			this.btnGuardar.Location = new System.Drawing.Point(400, 72);
			this.btnGuardar.Name = "btnGuardar";
			this.btnGuardar.Size = new System.Drawing.Size(104, 24);
			this.btnGuardar.TabIndex = 24;
			this.btnGuardar.Text = "Guardar";
			this.btnGuardar.Click += new System.EventHandler(this.BtnGuardarClick);
			// 
			// PacientesTelefono
			// 
			this.AutoScaleBaseSize = new System.Drawing.Size(5, 13);
			this.ClientSize = new System.Drawing.Size(512, 157);
			this.Controls.Add(this.lblPos);
			this.Controls.Add(this.btnLast);
			this.Controls.Add(this.btnNext);
			this.Controls.Add(this.btnPrev);
			this.Controls.Add(this.btnFirst);
			this.Controls.Add(this.btnImprimirListado);
			this.Controls.Add(this.btnImprimir);
			this.Controls.Add(this.btnCerrar);
			this.Controls.Add(this.btnBorrar);
			this.Controls.Add(this.btnGuardar);
			this.Controls.Add(this.btnNuevo);
			this.Controls.Add(this.lblContacto);
			this.Controls.Add(this.lblTelefono);
			this.Controls.Add(this.lblPacienteID);
			this.Controls.Add(this.txtContacto);
			this.Controls.Add(this.txtTelefono);
			this.Controls.Add(this.txtPacienteID);
			this.FormBorderStyle = System.Windows.Forms.FormBorderStyle.FixedDialog;
			this.MaximizeBox = false;
			this.MinimizeBox = false;
			this.Name = "PacientesTelefono";
			this.Text = "PacientesTelefono";
			this.Load += new System.EventHandler(this.PacientesTelefonoLoad);
			this.ResumeLayout(false);
		}
		#endregion
		
		void PacientesTelefonoLoad(object sender, System.EventArgs e)
		{
			this.CargarConfiguracionDatabase();
			AlertaLocal.setConnectionParameters(this.dbhost ,this.dbport ,this.dbuser ,this.dbpasoteword ,"formulacion");
			if ( this.Conectar(this.RecPosition) )
			{
				this.RecPosition = 0;
				this.CargarComandoUpdate();
				this.CargarComandoInsert();
				this.CargarComandoDelete();
				this.RecCount = ds.Tables[0].Rows.Count;
				
			    MostrarPosicion();
			    this.CargarRegistro(this.RecPosition);
			}
		}
		
		void MostrarPosicion(){
			this.lblPos.Text = (this.RecPosition+1).ToString() + " de " + this.RecCount.ToString();
		}

		void CargarRegistro( int numero){
			object[] campos;
			
			if( numero >=0 && numero < ds.Tables[0].Rows.Count)
			{
				campos = ds.Tables[0].Rows[numero].ItemArray;
				this.txtPacienteID.Text = campos[0].ToString();
				this.txtTelefono.Text = campos[1].ToString();
				this.txtContacto.Text = campos[2].ToString();
			}
		}

		
		void BtnNextClick(object sender, System.EventArgs e)
		{
			if( this.RecPosition < this.RecCount-1)
			this.RecPosition++;
			this.MostrarPosicion();
			this.CargarRegistro(this.RecPosition);
		}
		
		void BtnPrevClick(object sender, System.EventArgs e)
		{
			if( this.RecPosition > 0)
			this.RecPosition--;
			this.MostrarPosicion();
			this.CargarRegistro(this.RecPosition);
		}
		
		
		void BtnLastClick(object sender, System.EventArgs e)
		{
			this.RecPosition = this.RecCount-1;
			this.MostrarPosicion();
			this.CargarRegistro(this.RecPosition);
		}
		
		void BtnFirstClick(object sender, System.EventArgs e)
		{
			this.RecPosition = 0;
			this.MostrarPosicion();
			this.CargarRegistro(this.RecPosition);			
		}
		
		void BtnCerrarClick(object sender, System.EventArgs e)
		{
			this.Close();
		}
		
		void BtnNuevoClick(object sender, System.EventArgs e)
		{
			int l; // Nivel para nuevo
			AuthLevel al = new AuthLevel();
			al.setConnectionParameters(this.dbhost ,this.dbport ,this.dbuser ,this.dbpasoteword ,"formulacion");

			l = al.get_level(32); // Modulo 3: Pacientes, accion 2:Nuevo
			
			if(	this.currentlevel < l ){
				if( !AlertaLocal.registra_alerta("Error de seguridad al intentar aadir datos de pacientes con el nivel de autorizacion " + this.currentlevel.ToString()))
				{
					FM_Errores.MostrarError("Error al registrar alerta de seguridad");
				}

				FM_Errores.MostrarError("Seguridad","Su nivel de autorizacin no le permite aadir datos");
				return;
			}

			ds.Tables[0].Rows.Add(new Object[ds.Tables[0].Columns.Count]);
			this.RecCount = ds.Tables[0].Rows.Count;
			this.RecPosition = this.RecCount-1;
			
			this.MostrarPosicion();
			this.CargarRegistro(this.RecPosition);

		}
		
		void Borrado(object sender, System.Data.DataRowChangeEventArgs e)
		{
			DataRow[] pendientes;
			try{
			pendientes = ds.Tables[0].Select("", "", DataViewRowState.Deleted);
			FM_Errores.MostrarAviso("Borrado","Se han borrado " + adap.Update(pendientes).ToString() + " registros");
					ds.Clear();
        			adap.Fill(ds,"PacientesTelefono");
        			this.RecPosition=0;
        			this.RecCount = ds.Tables[0].Rows.Count;
        			this.CargarRegistro (this.RecPosition );
        			this.MostrarPosicion();

			}catch(Exception ex){
				FM_Errores.MostrarError("PacientesTelefono","No se puede borrar",ex);
			}
		}

		
		void BtnBorrarClick(object sender, System.EventArgs e)
		{
						int l; // Nivel para borrar
			AuthLevel al = new AuthLevel();
			al.setConnectionParameters(this.dbhost ,this.dbport ,this.dbuser ,this.dbpasoteword ,"formulacion");

			l = al.get_level(31); // Modulo 3: Pacientes, accion 3: Borrar
			
			if(	this.currentlevel < l ){
				if( !AlertaLocal.registra_alerta("Error de seguridad al intentar borrar los datos de pacientes con el nivel de autorizacion " + this.currentlevel.ToString()))
				{
					FM_Errores.MostrarError("Error al registrar alerta de seguridad");
				}

				FM_Errores.MostrarError("Seguridad","Su nivel de autorizacin no le permite borrar datos");
				return;
			}
			
			if (MessageBox.Show("Esta seguro?", "Confirmacin", MessageBoxButtons.YesNo, MessageBoxIcon.Question) == DialogResult.No)
				return;
			
			try{
			ds.Tables[0].RowDeleted += new System.Data.DataRowChangeEventHandler(Borrado);
			ds.Tables["Pacientes"].Rows.RemoveAt( this.RecPosition);
			}catch(Exception ex){
				FM_Errores.MostrarError("PacientesForm","No se puede borrar el paciente",ex);
			}
		}
		
		
		void GuardarRegistro(int numero){
			try{
			ds.Tables[0].Rows[numero].BeginEdit();
			ds.Tables[0].Rows[numero][0] = this.txtPacienteID.Text;
			ds.Tables[0].Rows[numero][1] = this.txtTelefono.Text;
			ds.Tables[0].Rows[numero][2] = this.txtContacto.Text;
			ds.Tables[0].Rows[numero].EndEdit();
			}catch(Exception ex){
				FM_Errores.MostrarError("PacientesTelefonoForm","No se puede modificar el registro",ex);
			}
			
		}

		void GuardarModificaciones()
		{
			try
    			{
        		int Modificaciones= 0; 
				DataRow[] pendientes;

					pendientes = ds.Tables[0].Select("", "", DataViewRowState.Deleted);
					Modificaciones = adap.Update(pendientes);
        		
        			Modificaciones += adap.Update(ds,"PacientesTelefono");
        			ds.Clear();
        			adap.Fill(ds,"PacientesTelefono");
        			this.RecPosition=0;
        			this.RecCount = ds.Tables[0].Rows.Count;
        			this.CargarRegistro (this.RecPosition );
        			this.MostrarPosicion();
        			FM_Errores.MostrarAviso("Actualizacion correcta","Actualizados "+Modificaciones+" registros");
        			
				}catch (Exception ex){
					FM_Errores.MostrarError("Actualizacion","Error actualizando datos",ex);
        	    }
			
		}

		
		void BtnGuardarClick(object sender, System.EventArgs e)
		{
			int l; // Nivel para guardar
			AuthLevel al = new AuthLevel();
			al.setConnectionParameters(this.dbhost ,this.dbport ,this.dbuser ,this.dbpasoteword ,"formulacion");

			l = al.get_level(33); // Modulo 3: Pacientes, accion 3: Modificar
			
			if(	this.currentlevel < l ){
				if( !AlertaLocal.registra_alerta("Error de seguridad al intentar modificar los datos de pacientes con el nivel de autorizacion " + this.currentlevel.ToString()))
				{
					FM_Errores.MostrarError("Error al registrar alerta de seguridad");
				}

				FM_Errores.MostrarError("Seguridad","Su nivel de autorizacin no le permite modificar los datos");
				return;
			}
			
			GuardarRegistro(this.RecPosition);
			GuardarModificaciones();
		}
		
		private void ImprimirListado(int from, int dest)
		{
			try{
			Formulacion.Impresiones docMaterial = new Formulacion.Impresiones();
			PrintPreviewDialog prevDialog = new PrintPreviewDialog();
			PrintDialog prdialog = new PrintDialog();
			
			docMaterial.ImprimirCabezera();
			docMaterial.NuevoTexto("Listado de Telefonos de Pacientes.");
			
			object[] a;
			
			for(int i=from ; i<dest; ++i)
			{
			a = ds.Tables[0].Rows[i].ItemArray;
			docMaterial.NuevaLinea();
			docMaterial.NuevoTexto("PacienteID: " + a[0].ToString());
			docMaterial.NuevoTexto("Telefono: " + a[1].ToString());
			docMaterial.NuevoTexto("Contacto: " + a[2].ToString());
			docMaterial.NuevoTexto("");
			}
			
			prevDialog.Document = docMaterial;
			prdialog.Document = docMaterial;
			
			docMaterial.PrintPage += new PrintPageEventHandler(docMaterial.ImprimirElementos);
			docMaterial.BeginPrint += new PrintEventHandler (docMaterial.Reajustar);
			
			// Esto esta por ser configurable en fichero XML o DB
			// docMaterial.MuestraPrefsPagina();
			
			
			// Esto tambien deberia ser configurable
			prevDialog.Text = "Previsualizacion del listado de telefonos de pacientes seleccionados";
			prevDialog.ShowDialog();
			
			if (prdialog.ShowDialog()== DialogResult.OK)
			{
				docMaterial.Print();
			}

			
			}catch(Exception ex){
				FM_Errores.MostrarError("Impresion","No se puede imprimir el listado de telefonos",ex);
			}

		}

		
		
		void BtnImprimirListadoClick(object sender, System.EventArgs e)
		{
			this.ImprimirListado(0,ds.Tables[0].Rows.Count);
		}
		
		void BtnImprimirClick(object sender, System.EventArgs e)
		{
			this.ImprimirListado(this.RecPosition,this.RecPosition+1);
		}
		
	}
}
