/*
 * 
 *  ProveedoresForm
 * 
 * 
 * (C) Alvaro Cortes. 2007. alvarocortesc@gmail.com
 * 
 * 
 * 
 */

using System;
using System.Drawing;
using System.Windows.Forms;
using System.Drawing.Printing;
using MySql.Data.MySqlClient;
using System.Data;

namespace FormulacionMagistral
{
	/// <summary>
	/// Description of ProveedoresForm.
	/// </summary>
	public class ProveedoresForm : System.Windows.Forms.Form
	{
		private System.Windows.Forms.Label lblID;
		private System.Windows.Forms.Button btnFirst;
		private System.Windows.Forms.Button btnImprimirListado;
		private System.Windows.Forms.Button btnImprimir;
		private System.Windows.Forms.Button btnNuevo;
		private System.Windows.Forms.TextBox txtCP;
		private System.Windows.Forms.Button btnGuardar;
		private System.Windows.Forms.Button btnBuscar;
		private System.Windows.Forms.Button btnNext;
		private System.Windows.Forms.Label lblDireccion;
		private System.Windows.Forms.TextBox txtID;
		private System.Windows.Forms.ComboBox cmbBuscar;
		private System.Windows.Forms.Label lblPosicion;
		private System.Windows.Forms.Button btnPrevious;
		private System.Windows.Forms.TextBox txteMail;
		private System.Windows.Forms.Label lblBuscar;
		private System.Windows.Forms.Label lbleMail;
		private System.Windows.Forms.Label lblNombre;
		private System.Windows.Forms.Button btnBorrar;
		private System.Windows.Forms.Button btnVerTelefonos;
		private System.Windows.Forms.TextBox txtNombre;
		private System.Windows.Forms.Label lblProvincia;
		private System.Windows.Forms.TextBox txtBuscar;
		private System.Windows.Forms.Button btnLast;
		private System.Windows.Forms.Button btnProvincias;
		private System.Windows.Forms.Label lblCP;
		private System.Windows.Forms.TextBox txtDireccion;
		private System.Windows.Forms.Label lblCiudad;
		private System.Windows.Forms.Label lblBuscaren;
		private System.Windows.Forms.TextBox txtProvincia;
		private System.Windows.Forms.TextBox txtCiudad;
		
		
		// Algunos objetos para la conexion y obtencion de datos
		private MySqlConnection conn;
		private MySqlDataAdapter adap;  // Adapter general 
		private System.Data.DataSet ds;
		private MySqlParameter parm;
		
		// Algunas variables para emular el CurrencyManager defectuoso de Mono
		
		private int RecCount;
		private int RecPosition;
				
		// Para cargar preferencias de la BD
		private Formulacion.PreferenciasDB DBPrefs;
		
		// Informacion para conexion BD
		private string dbhost;
		private string dbport;
		private string dbuser;
		private string dbpasoteword;
		
		
		// Nivel de acceso
		private int currentlevel;
		
		private Alertas AlertaLocal; // Alertas

		/// <summary>
		/// Contructor de proveedores
		/// </summary>
		/// <param name="nivel">Nivel actual de autorizacion</param>
		public ProveedoresForm(int nivel)
		{
			//
			// The InitializeComponent() call is required for Windows Forms designer support.
			//
			InitializeComponent();
			
			DBPrefs = new Formulacion.PreferenciasDB();
			DBPrefs.AsignarNmbFichero("PrefDataBase.xml");
			
			this.currentlevel = nivel;
			this.RecPosition = -1;
			
			AlertaLocal = new Alertas();
			
		}
		
		/// <summary>
		/// Contructor de proveedores
		/// </summary>
		/// <param name="nivel">Nivel actual de autorizacion</param>
		/// <param name="registro">ID de proveedor a cargar</param>
		public ProveedoresForm(int nivel, int registro)
		{
			//
			// The InitializeComponent() call is required for Windows Forms designer support.
			//
			InitializeComponent();
			
			DBPrefs = new Formulacion.PreferenciasDB();
			DBPrefs.AsignarNmbFichero("PrefDataBase.xml");
			
			this.currentlevel = nivel;
			this.RecPosition = registro;
			
			AlertaLocal = new Alertas();
		}

		/// <summary>
		/// Obtiene el id del registro actual
		/// </summary>
		/// <returns>Devuelve un entero del ID del registro</returns>
		public int getcurrentid(){
			int n;
			try{
				n = Convert.ToInt32( this.txtID.Text);
				return n;
			}catch(Exception ex){
				FM_Errores.MostrarError("GetCurrentID","No se puede obtener el ID actual",ex);
				return -1;
			}
		}
		
		
		/// <summary>
		/// Carga la configuracin de la base de datos en la vars
		/// de la clase
		/// </summary>
		void CargarConfiguracionDatabase(){
			string[] prf;
			if ( this.DBPrefs.LeerFichero() )
			{
				prf = this.DBPrefs.CargarPreferenciasDB();
				
				for( int i = 0; i < prf.Length; ++i)
				{
					switch(i){
						case 0: this.dbhost = prf[0]; break;
						case 1: this.dbport = prf[1]; break;
						case 3: this.dbuser = prf[2]; break;
						case 4: this.dbpasoteword = prf[3]; break;
					
					}
				}
				this.DBPrefs.CerrarEntrada();
			}
		}
		
		private bool Conectar(int registro){
			try{
		 	conn = new MySqlConnection("host="+this.dbhost+";port=" + this.dbport + ";user id="+this.dbuser+";password="+this.dbpasoteword+ ";database=formulacion");
		 	adap = new MySqlDataAdapter();
			ds = new System.Data.DataSet();
			if( registro >= 0){
		 		adap.SelectCommand = new MySqlCommand("SELECT * FROM proveedores WHERE ProveedorID="+ registro.ToString() + ";",conn);
			}
		 	else{
			 	adap.SelectCommand = new MySqlCommand("SELECT * FROM proveedores;",conn);
				}
			adap.Fill(ds,"Proveedores");
		 	
		 	
		 	return true;
			}catch(MySqlException ex){
				FM_Errores.MostrarError("ProveedoresForm","Error relacionado con base de datos",ex);
				return false;
			}catch(Exception e){
				FM_Errores.MostrarError("ProveedoresForm","Error general. No se puede cargar la informacion de proveedores",e);
				return false;
			}
		 	
		}
		
		private void CargarComandoUpdate(){
			adap.UpdateCommand = new MySqlCommand("Update proveedores Set ProveedorID = ?ProveedorID, Nombre = ?Nombre, Direccion = ?Direccion ,Ciudad = ?Ciudad, CodigoPostal = ?CodigoPostal, eMail = ?eMail WHERE ProveedorID = ?ProveedorIDA",conn);
			
			parm = adap.UpdateCommand.Parameters.Add("?ProveedorIDA", MySqlDbType.Int32);
			parm.SourceColumn = "ProveedorID";
			parm.SourceVersion = DataRowVersion.Original;

			parm = adap.UpdateCommand.Parameters.Add("?ProveedorID", MySqlDbType.Int32);
			parm.SourceColumn = "ProveedorID";
			parm.SourceVersion = DataRowVersion.Current;

			
			parm = adap.UpdateCommand.Parameters.Add("?Nombre", MySqlDbType.VarChar, 50 );
			parm.SourceColumn = "Nombre";
			parm.SourceVersion = DataRowVersion.Current;
			
			
			parm = adap.UpdateCommand.Parameters.Add("?Direccion", MySqlDbType.VarChar, 250 );
			parm.SourceColumn = "Direccion";
			parm.SourceVersion = DataRowVersion.Current;
			
			parm = adap.UpdateCommand.Parameters.Add("?Ciudad", MySqlDbType.VarChar, 250 );
			parm.SourceColumn = "Ciudad";
			parm.SourceVersion = DataRowVersion.Current;
			
			parm = adap.UpdateCommand.Parameters.Add("?CodigoPostal",MySqlDbType.VarChar, 20 );
			parm.SourceColumn = "CodigoPostal";
			parm.SourceVersion = DataRowVersion.Current;
			
			parm = adap.UpdateCommand.Parameters.Add("?eMail", MySqlDbType.VarChar, 250 );
			parm.SourceColumn = "eMail";
			parm.SourceVersion = DataRowVersion.Current;
			
			

		}
		
		private void CargarComandoDelete(){
			adap.DeleteCommand = new MySqlCommand("DELETE FROM proveedores WHERE ProveedorID = ?ProveedorID",conn);
			
			parm = adap.DeleteCommand.Parameters.Add("?ProveedorID", MySqlDbType.Int32);
			parm.SourceColumn = "ProveedorID";
			parm.SourceVersion = DataRowVersion.Current;
			
			
		}
		
		private void CargarComandoInsert(){
			adap.InsertCommand = new MySqlCommand("Insert into proveedores(ProveedorID, Nombre, Direccion,Ciudad, CodigoPostal, eMail) VALUES (?ProveedorID,?Nombre,?Direccion,?Ciudad,?CodigoPostal,?eMail)",conn);
			
			parm = adap.InsertCommand.Parameters.Add("?ProveedorID", MySqlDbType.Int32);
			parm.SourceColumn = "ProveedorID";
			parm.SourceVersion = DataRowVersion.Current;
			
			parm = adap.InsertCommand.Parameters.Add("?Nombre", MySqlDbType.VarChar, 50 );
			parm.SourceColumn = "Nombre";
			parm.SourceVersion = DataRowVersion.Current;
			
			parm = adap.InsertCommand.Parameters.Add("?Direccion", MySqlDbType.VarChar, 250 );
			parm.SourceColumn = "Direccion";
			parm.SourceVersion = DataRowVersion.Current;

			parm = adap.InsertCommand.Parameters.Add("?Ciudad", MySqlDbType.VarChar, 250 );
			parm.SourceColumn = "Ciudad";
			parm.SourceVersion = DataRowVersion.Current;
			
			parm = adap.InsertCommand.Parameters.Add("?CodigoPostal", MySqlDbType.VarChar, 20 );
			parm.SourceColumn = "CodigoPostal";
			parm.SourceVersion = DataRowVersion.Current;
			
			parm = adap.InsertCommand.Parameters.Add("?eMail", MySqlDbType.VarChar, 250 );
			parm.SourceColumn = "eMail";
			parm.SourceVersion = DataRowVersion.Current;
			
		}

		
		#region Windows Forms Designer generated code
		/// <summary>
		/// This method is required for Windows Forms designer support.
		/// Do not change the method contents inside the source code editor. The Forms designer might
		/// not be able to load this method if it was changed manually.
		/// </summary>
		private void InitializeComponent() {
			this.txtCiudad = new System.Windows.Forms.TextBox();
			this.txtProvincia = new System.Windows.Forms.TextBox();
			this.lblBuscaren = new System.Windows.Forms.Label();
			this.lblCiudad = new System.Windows.Forms.Label();
			this.txtDireccion = new System.Windows.Forms.TextBox();
			this.lblCP = new System.Windows.Forms.Label();
			this.btnProvincias = new System.Windows.Forms.Button();
			this.btnLast = new System.Windows.Forms.Button();
			this.txtBuscar = new System.Windows.Forms.TextBox();
			this.lblProvincia = new System.Windows.Forms.Label();
			this.txtNombre = new System.Windows.Forms.TextBox();
			this.btnVerTelefonos = new System.Windows.Forms.Button();
			this.btnBorrar = new System.Windows.Forms.Button();
			this.lblNombre = new System.Windows.Forms.Label();
			this.lbleMail = new System.Windows.Forms.Label();
			this.lblBuscar = new System.Windows.Forms.Label();
			this.txteMail = new System.Windows.Forms.TextBox();
			this.btnPrevious = new System.Windows.Forms.Button();
			this.lblPosicion = new System.Windows.Forms.Label();
			this.cmbBuscar = new System.Windows.Forms.ComboBox();
			this.txtID = new System.Windows.Forms.TextBox();
			this.lblDireccion = new System.Windows.Forms.Label();
			this.btnNext = new System.Windows.Forms.Button();
			this.btnBuscar = new System.Windows.Forms.Button();
			this.btnGuardar = new System.Windows.Forms.Button();
			this.txtCP = new System.Windows.Forms.TextBox();
			this.btnNuevo = new System.Windows.Forms.Button();
			this.btnImprimir = new System.Windows.Forms.Button();
			this.btnImprimirListado = new System.Windows.Forms.Button();
			this.btnFirst = new System.Windows.Forms.Button();
			this.lblID = new System.Windows.Forms.Label();
			this.SuspendLayout();
			// 
			// txtCiudad
			// 
			this.txtCiudad.Location = new System.Drawing.Point(128, 152);
			this.txtCiudad.Name = "txtCiudad";
			this.txtCiudad.Size = new System.Drawing.Size(200, 20);
			this.txtCiudad.TabIndex = 38;
			this.txtCiudad.Text = "";
			// 
			// txtProvincia
			// 
			this.txtProvincia.Enabled = false;
			this.txtProvincia.Location = new System.Drawing.Point(128, 184);
			this.txtProvincia.Name = "txtProvincia";
			this.txtProvincia.Size = new System.Drawing.Size(200, 20);
			this.txtProvincia.TabIndex = 40;
			this.txtProvincia.Text = "";
			// 
			// lblBuscaren
			// 
			this.lblBuscaren.Location = new System.Drawing.Point(328, 16);
			this.lblBuscaren.Name = "lblBuscaren";
			this.lblBuscaren.Size = new System.Drawing.Size(32, 16);
			this.lblBuscaren.TabIndex = 53;
			this.lblBuscaren.Text = "en";
			// 
			// lblCiudad
			// 
			this.lblCiudad.Location = new System.Drawing.Point(16, 152);
			this.lblCiudad.Name = "lblCiudad";
			this.lblCiudad.Size = new System.Drawing.Size(80, 16);
			this.lblCiudad.TabIndex = 37;
			this.lblCiudad.Text = "Ciudad";
			// 
			// txtDireccion
			// 
			this.txtDireccion.Location = new System.Drawing.Point(128, 120);
			this.txtDireccion.Name = "txtDireccion";
			this.txtDireccion.Size = new System.Drawing.Size(200, 20);
			this.txtDireccion.TabIndex = 56;
			this.txtDireccion.Text = "";
			// 
			// lblCP
			// 
			this.lblCP.Location = new System.Drawing.Point(16, 216);
			this.lblCP.Name = "lblCP";
			this.lblCP.Size = new System.Drawing.Size(80, 24);
			this.lblCP.TabIndex = 42;
			this.lblCP.Text = "C.P.";
			// 
			// btnProvincias
			// 
			this.btnProvincias.Location = new System.Drawing.Point(336, 184);
			this.btnProvincias.Name = "btnProvincias";
			this.btnProvincias.Size = new System.Drawing.Size(32, 24);
			this.btnProvincias.TabIndex = 41;
			this.btnProvincias.Text = "...";
			// 
			// btnLast
			// 
			this.btnLast.Location = new System.Drawing.Point(416, 312);
			this.btnLast.Name = "btnLast";
			this.btnLast.Size = new System.Drawing.Size(80, 24);
			this.btnLast.TabIndex = 62;
			this.btnLast.Text = "-->";
			this.btnLast.Click += new System.EventHandler(this.BtnLastClick);
			// 
			// txtBuscar
			// 
			this.txtBuscar.Location = new System.Drawing.Point(128, 16);
			this.txtBuscar.Name = "txtBuscar";
			this.txtBuscar.Size = new System.Drawing.Size(192, 20);
			this.txtBuscar.TabIndex = 51;
			this.txtBuscar.Text = "";
			// 
			// lblProvincia
			// 
			this.lblProvincia.Location = new System.Drawing.Point(16, 184);
			this.lblProvincia.Name = "lblProvincia";
			this.lblProvincia.Size = new System.Drawing.Size(80, 24);
			this.lblProvincia.TabIndex = 39;
			this.lblProvincia.Text = "Provincina";
			// 
			// txtNombre
			// 
			this.txtNombre.Location = new System.Drawing.Point(128, 88);
			this.txtNombre.Name = "txtNombre";
			this.txtNombre.Size = new System.Drawing.Size(200, 20);
			this.txtNombre.TabIndex = 33;
			this.txtNombre.Text = "";
			// 
			// btnVerTelefonos
			// 
			this.btnVerTelefonos.Location = new System.Drawing.Point(128, 280);
			this.btnVerTelefonos.Name = "btnVerTelefonos";
			this.btnVerTelefonos.Size = new System.Drawing.Size(208, 24);
			this.btnVerTelefonos.TabIndex = 66;
			this.btnVerTelefonos.Text = "Ver Telefonos";
			this.btnVerTelefonos.Click += new System.EventHandler(this.BtnVerTelefonosClick);
			// 
			// btnBorrar
			// 
			this.btnBorrar.Location = new System.Drawing.Point(408, 136);
			this.btnBorrar.Name = "btnBorrar";
			this.btnBorrar.Size = new System.Drawing.Size(80, 24);
			this.btnBorrar.TabIndex = 47;
			this.btnBorrar.Text = "Borrar";
			this.btnBorrar.Click += new System.EventHandler(this.BtnBorrarClick);
			// 
			// lblNombre
			// 
			this.lblNombre.Location = new System.Drawing.Point(16, 88);
			this.lblNombre.Name = "lblNombre";
			this.lblNombre.Size = new System.Drawing.Size(96, 16);
			this.lblNombre.TabIndex = 34;
			this.lblNombre.Text = "Nombre";
			// 
			// lbleMail
			// 
			this.lbleMail.Location = new System.Drawing.Point(16, 248);
			this.lbleMail.Name = "lbleMail";
			this.lbleMail.Size = new System.Drawing.Size(80, 16);
			this.lbleMail.TabIndex = 44;
			this.lbleMail.Text = "e-Mail";
			// 
			// lblBuscar
			// 
			this.lblBuscar.Location = new System.Drawing.Point(16, 16);
			this.lblBuscar.Name = "lblBuscar";
			this.lblBuscar.Size = new System.Drawing.Size(80, 16);
			this.lblBuscar.TabIndex = 50;
			this.lblBuscar.Text = "Buscar por:";
			// 
			// txteMail
			// 
			this.txteMail.Location = new System.Drawing.Point(128, 248);
			this.txteMail.Name = "txteMail";
			this.txteMail.Size = new System.Drawing.Size(200, 20);
			this.txteMail.TabIndex = 45;
			this.txteMail.Text = "";
			// 
			// btnPrevious
			// 
			this.btnPrevious.Location = new System.Drawing.Point(104, 312);
			this.btnPrevious.Name = "btnPrevious";
			this.btnPrevious.Size = new System.Drawing.Size(80, 24);
			this.btnPrevious.TabIndex = 60;
			this.btnPrevious.Text = "<-";
			this.btnPrevious.Click += new System.EventHandler(this.BtnPreviousClick);
			// 
			// lblPosicion
			// 
			this.lblPosicion.Location = new System.Drawing.Point(192, 320);
			this.lblPosicion.Name = "lblPosicion";
			this.lblPosicion.Size = new System.Drawing.Size(112, 16);
			this.lblPosicion.TabIndex = 63;
			this.lblPosicion.Text = "0 de 0";
			this.lblPosicion.TextAlign = System.Drawing.ContentAlignment.MiddleCenter;
			// 
			// cmbBuscar
			// 
			this.cmbBuscar.Items.AddRange(new object[] {
						"Nombre",
						"Direccion",
						"Ciudad",
						"CodigoPostal",
						"eMail"});
			this.cmbBuscar.Location = new System.Drawing.Point(368, 16);
			this.cmbBuscar.Name = "cmbBuscar";
			this.cmbBuscar.Size = new System.Drawing.Size(120, 21);
			this.cmbBuscar.TabIndex = 52;
			// 
			// txtID
			// 
			this.txtID.Location = new System.Drawing.Point(128, 56);
			this.txtID.Name = "txtID";
			this.txtID.Size = new System.Drawing.Size(200, 20);
			this.txtID.TabIndex = 58;
			this.txtID.Text = "";
			// 
			// lblDireccion
			// 
			this.lblDireccion.Location = new System.Drawing.Point(16, 120);
			this.lblDireccion.Name = "lblDireccion";
			this.lblDireccion.Size = new System.Drawing.Size(80, 16);
			this.lblDireccion.TabIndex = 55;
			this.lblDireccion.Text = "Direccin";
			// 
			// btnNext
			// 
			this.btnNext.Location = new System.Drawing.Point(320, 312);
			this.btnNext.Name = "btnNext";
			this.btnNext.Size = new System.Drawing.Size(80, 24);
			this.btnNext.TabIndex = 61;
			this.btnNext.Text = "->";
			this.btnNext.Click += new System.EventHandler(this.BtnNextClick);
			// 
			// btnBuscar
			// 
			this.btnBuscar.Location = new System.Drawing.Point(408, 48);
			this.btnBuscar.Name = "btnBuscar";
			this.btnBuscar.Size = new System.Drawing.Size(80, 24);
			this.btnBuscar.TabIndex = 54;
			this.btnBuscar.Text = "Buscar";
			this.btnBuscar.Click += new System.EventHandler(this.BtnBuscarClick);
			// 
			// btnGuardar
			// 
			this.btnGuardar.Location = new System.Drawing.Point(408, 104);
			this.btnGuardar.Name = "btnGuardar";
			this.btnGuardar.Size = new System.Drawing.Size(80, 24);
			this.btnGuardar.TabIndex = 46;
			this.btnGuardar.Text = "Guardar";
			this.btnGuardar.Click += new System.EventHandler(this.BtnGuardarClick);
			// 
			// txtCP
			// 
			this.txtCP.Location = new System.Drawing.Point(128, 216);
			this.txtCP.Name = "txtCP";
			this.txtCP.Size = new System.Drawing.Size(200, 20);
			this.txtCP.TabIndex = 43;
			this.txtCP.Text = "";
			// 
			// btnNuevo
			// 
			this.btnNuevo.Location = new System.Drawing.Point(408, 168);
			this.btnNuevo.Name = "btnNuevo";
			this.btnNuevo.Size = new System.Drawing.Size(80, 24);
			this.btnNuevo.TabIndex = 49;
			this.btnNuevo.Text = "Nuevo";
			this.btnNuevo.Click += new System.EventHandler(this.BtnNuevoClick);
			// 
			// btnImprimir
			// 
			this.btnImprimir.Location = new System.Drawing.Point(408, 200);
			this.btnImprimir.Name = "btnImprimir";
			this.btnImprimir.Size = new System.Drawing.Size(80, 24);
			this.btnImprimir.TabIndex = 64;
			this.btnImprimir.Text = "Imprimir";
			this.btnImprimir.Click += new System.EventHandler(this.BtnImprimirClick);
			// 
			// btnImprimirListado
			// 
			this.btnImprimirListado.Location = new System.Drawing.Point(408, 232);
			this.btnImprimirListado.Name = "btnImprimirListado";
			this.btnImprimirListado.Size = new System.Drawing.Size(80, 24);
			this.btnImprimirListado.TabIndex = 65;
			this.btnImprimirListado.Text = "ImprimirLista";
			this.btnImprimirListado.Click += new System.EventHandler(this.BtnImprimirListadoClick);
			// 
			// btnFirst
			// 
			this.btnFirst.Location = new System.Drawing.Point(16, 312);
			this.btnFirst.Name = "btnFirst";
			this.btnFirst.Size = new System.Drawing.Size(80, 24);
			this.btnFirst.TabIndex = 59;
			this.btnFirst.Text = "<--";
			this.btnFirst.Click += new System.EventHandler(this.BtnFirstClick);
			// 
			// lblID
			// 
			this.lblID.Location = new System.Drawing.Point(16, 56);
			this.lblID.Name = "lblID";
			this.lblID.Size = new System.Drawing.Size(104, 16);
			this.lblID.TabIndex = 57;
			this.lblID.Text = "ID";
			// 
			// ProveedoresForm
			// 
			this.AutoScaleBaseSize = new System.Drawing.Size(5, 13);
			this.ClientSize = new System.Drawing.Size(512, 341);
			this.Controls.Add(this.btnVerTelefonos);
			this.Controls.Add(this.btnImprimirListado);
			this.Controls.Add(this.btnImprimir);
			this.Controls.Add(this.lblPosicion);
			this.Controls.Add(this.btnLast);
			this.Controls.Add(this.btnNext);
			this.Controls.Add(this.btnPrevious);
			this.Controls.Add(this.btnFirst);
			this.Controls.Add(this.txtID);
			this.Controls.Add(this.lblID);
			this.Controls.Add(this.txtDireccion);
			this.Controls.Add(this.lblDireccion);
			this.Controls.Add(this.btnBuscar);
			this.Controls.Add(this.lblBuscaren);
			this.Controls.Add(this.cmbBuscar);
			this.Controls.Add(this.txtBuscar);
			this.Controls.Add(this.lblBuscar);
			this.Controls.Add(this.btnNuevo);
			this.Controls.Add(this.btnBorrar);
			this.Controls.Add(this.btnGuardar);
			this.Controls.Add(this.txteMail);
			this.Controls.Add(this.lbleMail);
			this.Controls.Add(this.txtCP);
			this.Controls.Add(this.lblCP);
			this.Controls.Add(this.btnProvincias);
			this.Controls.Add(this.txtProvincia);
			this.Controls.Add(this.lblProvincia);
			this.Controls.Add(this.txtCiudad);
			this.Controls.Add(this.lblCiudad);
			this.Controls.Add(this.txtNombre);
			this.Controls.Add(this.lblNombre);
			this.FormBorderStyle = System.Windows.Forms.FormBorderStyle.FixedDialog;
			this.MaximizeBox = false;
			this.MinimizeBox = false;
			this.Name = "ProveedoresForm";
			this.Text = "Proveedores (Modo ficha)";
			this.Closing += new System.ComponentModel.CancelEventHandler(this.ProveedoresFormClosing);
			this.Load += new System.EventHandler(this.ProveedoresFormLoad);
			this.ResumeLayout(false);
		}
		#endregion
		void ProveedoresFormLoad(object sender, System.EventArgs e)
		{
			this.CargarConfiguracionDatabase();
			AlertaLocal.setConnectionParameters(this.dbhost ,this.dbport ,this.dbuser ,this.dbpasoteword ,"formulacion");
			if ( this.Conectar(this.RecPosition) )
			{
				this.CargarComandoUpdate();
				this.CargarComandoInsert();
				this.CargarComandoDelete();
				this.RecPosition = 0;
				this.RecCount = ds.Tables[0].Rows.Count;
			    MostrarPosicion();
			    this.CargarRegistro(0);
			}
		}
		
		void MostrarPosicion(){
			lblPosicion.Text = (this.RecPosition + 1) + 
                             " de " + this.RecCount;

		}
		
		
		void BtnGuardarClick(object sender, System.EventArgs e)
		{

			int l; // Nivel para guardar
			AuthLevel al = new AuthLevel();
			al.setConnectionParameters(this.dbhost ,this.dbport ,this.dbuser ,this.dbpasoteword ,"formulacion");

			l = al.get_level(23); // Modulo 2: Proveedores, accion 3: Modificar
			
			if(	this.currentlevel < l ){
				if( !AlertaLocal.registra_alerta("Error de seguridad al intentar modificar los datos de proveedores con el nivel de autorizacion " + this.currentlevel.ToString()))
				{
					FM_Errores.MostrarError("Error al registrar alerta de seguridad");
				}

				FM_Errores.MostrarError("Seguridad","Su nivel de autorizacin no le permite modificar los datos");
				return;
			}
			
			GuardarRegistro(this.RecPosition);
			GuardarModificaciones();
		}
		
		
		void GuardarModificaciones()
		{
			
			try
    			{
        		int ModificacionesProveedores = 0; 
				DataRow[] pendientes;

					pendientes = ds.Tables[0].Select("", "", DataViewRowState.Deleted);
					ModificacionesProveedores = adap.Update(pendientes);
        		
        			ModificacionesProveedores += adap.Update(ds,"Proveedores");
        			ds.Clear();
        			adap.Fill(ds,"Proveedores");
        			this.RecPosition=0;
        			this.RecCount = ds.Tables[0].Rows.Count;
        			this.CargarRegistro (this.RecPosition );
        			this.MostrarPosicion();
        			FM_Errores.MostrarAviso("Actualizacion correcta","Actualizados "+ModificacionesProveedores+" registros");
        			
				}catch (Exception ex){
					FM_Errores.MostrarError("Actualizacion","Error actualizando datos",ex);
        	    }
			
		}
		void BtnFirstClick(object sender, System.EventArgs e)
		{
			this.RecPosition = 0;
			this.MostrarPosicion();
			this.CargarRegistro(this.RecPosition);
		}
		
		void BtnPreviousClick(object sender, System.EventArgs e)
		{
			if( this.RecPosition > 0)
			this.RecPosition--;
			this.MostrarPosicion();
			this.CargarRegistro(this.RecPosition);
			
		}
		
		void BtnNextClick(object sender, System.EventArgs e)
		{
			if( this.RecPosition < this.RecCount-1)
			this.RecPosition++;
			this.MostrarPosicion();
			this.CargarRegistro(this.RecPosition);
		}
		
		void BtnLastClick(object sender, System.EventArgs e)
		{
			this.RecPosition = this.RecCount-1;
			this.MostrarPosicion();
			this.CargarRegistro(this.RecPosition);
		}
		
		void BtnNuevoClick(object sender, System.EventArgs e)
		{
			int l; // Nivel para nuevo
			AuthLevel al = new AuthLevel();
			al.setConnectionParameters(this.dbhost ,this.dbport ,this.dbuser ,this.dbpasoteword ,"formulacion");

			l = al.get_level(22); // Modulo 2: Proveedores, accion 2:Nuevo
			
			if(	this.currentlevel < l ){
				if( !AlertaLocal.registra_alerta("Error de seguridad al intentar aadir datos de proveedores con el nivel de autorizacion " + this.currentlevel.ToString()))
				{
					FM_Errores.MostrarError("Error al registrar alerta de seguridad");
				}

				FM_Errores.MostrarError("Seguridad","Su nivel de autorizacin no le permite aadir datos");
				return;
			}

			ds.Tables[0].Rows.Add(new Object[ds.Tables[0].Columns.Count]);
			this.RecCount = ds.Tables[0].Rows.Count;
			this.RecPosition = this.RecCount-1;
			
			this.MostrarPosicion();
			this.CargarRegistro(this.RecPosition);
			
			
		}
		void Borrado(object sender, System.Data.DataRowChangeEventArgs e)
		{
			DataRow[] pendientes;
			try{
			pendientes = ds.Tables[0].Select("", "", DataViewRowState.Deleted);
			FM_Errores.MostrarAviso("Borrado","Se han borrado " + adap.Update(pendientes).ToString() + " registros");
					ds.Clear();
        			adap.Fill(ds,"Proveedores");
        			this.RecPosition=0;
        			this.RecCount = ds.Tables[0].Rows.Count;
        			this.CargarRegistro (this.RecPosition );
        			this.MostrarPosicion();

			}catch(Exception ex){
				FM_Errores.MostrarError("ProveedoresForm","No se puede borrar",ex);
			}
		}
		void BtnBorrarClick(object sender, System.EventArgs e)
		{
			int l; // Nivel para borrar
			AuthLevel al = new AuthLevel();
			al.setConnectionParameters(this.dbhost ,this.dbport ,this.dbuser ,this.dbpasoteword ,"formulacion");

			l = al.get_level(21); // Modulo 2: Proveedores, accion 3: Borrar
			
			if(	this.currentlevel < l ){
				if( !AlertaLocal.registra_alerta("Error de seguridad al intentar borrar los datos de proveedores con el nivel de autorizacion " + this.currentlevel.ToString()))
				{
					FM_Errores.MostrarError("Error al registrar alerta de seguridad");
				}

				FM_Errores.MostrarError("Seguridad","Su nivel de autorizacin no le permite borrar datos");
				return;
			}

			if (MessageBox.Show("Esta seguro?", "Confirmacin", MessageBoxButtons.YesNo, MessageBoxIcon.Question) == DialogResult.No)
				return;
			
			try{
			ds.Tables[0].RowDeleted += new System.Data.DataRowChangeEventHandler(Borrado);
			ds.Tables["Proveedores"].Rows.RemoveAt( this.RecPosition);
			}catch(Exception ex){
				FM_Errores.MostrarError("Error Proveedores","No se puede borrar el proveedor",ex);
			}
		}
		
		
		void CargarRegistro( int numero){
			object[] campos;
			
			if( numero >=0 && numero < ds.Tables[0].Rows.Count)
			{
				campos = ds.Tables[0].Rows[numero].ItemArray;
				
				this.txtID.Text = campos[0].ToString();
				this.txtNombre.Text = campos[1].ToString();
				this.txtDireccion.Text = campos[2].ToString();
				this.txtCiudad.Text = campos[3].ToString();
				this.txtCP.Text  = campos[4].ToString();
				this.txteMail.Text = campos[6].ToString();
				
			}
			
		}
		
		void GuardarRegistro(int numero){
			try{
			ds.Tables[0].Rows[numero].BeginEdit();
			ds.Tables[0].Rows[numero][0] = this.txtID.Text;
			ds.Tables[0].Rows[numero][1] = this.txtNombre.Text;
			ds.Tables[0].Rows[numero][2] = this.txtDireccion.Text;
			ds.Tables[0].Rows[numero][3] = this.txtCiudad.Text;
			ds.Tables[0].Rows[numero][4] = this.txtCP.Text;
			ds.Tables[0].Rows[numero][6] = this.txteMail.Text;
			ds.Tables[0].Rows[numero].EndEdit();
			}catch(Exception ex){
				FM_Errores.MostrarError("ProveedoresForm","No se puede modificar el registro",ex);
			}
			
		}
		
		void ProveedoresFormClosing(object sender, System.ComponentModel.CancelEventArgs e)
		{
			if( ds.HasChanges() ){
				if (MessageBox.Show("Hay cambios pendientes, desea guardarlos antes de cerrar?","Confirmacin", MessageBoxButtons.YesNo, MessageBoxIcon.Question) == DialogResult.Yes)
				{
					int l; // Nivel para guardar
					AuthLevel al = new AuthLevel();
					al.setConnectionParameters(this.dbhost ,this.dbport ,this.dbuser ,this.dbpasoteword ,"formulacion");

					l = al.get_level(23); // Modulo 2: Proveedores, accion 3: Modificar
			
					if(	this.currentlevel < l ){
						if( !AlertaLocal.registra_alerta("Error de seguridad al intentar modificar los datos de proveedores con el nivel de autorizacion " + this.currentlevel.ToString()))
						{
						FM_Errores.MostrarError("Error al registrar alerta de seguridad");
						}

						FM_Errores.MostrarError("Seguridad","Su nivel de autorizacin no le permite modificar los datos");
						return;
					}
					GuardarModificaciones();				
				}
					
			}
			
		}
		
		void BtnVerTelefonosClick(object sender, System.EventArgs e)
		{
			ProveedoresTelefono pt = new ProveedoresTelefono(this.currentlevel, Convert.ToInt32(this.txtID.Text));
			pt.ShowDialog();
			pt.Dispose();
		}
		
		
		private void ImprimirListado(int from, int dest)
		{
			try{
			Formulacion.Impresiones docMaterial = new Formulacion.Impresiones();
			PrintPreviewDialog prevDialog = new PrintPreviewDialog();
			PrintDialog prdialog = new PrintDialog();
			
			docMaterial.ImprimirCabezera();
			docMaterial.NuevoTexto("Listado de Proveedores.");
			
			object[] a;
			
			for(int i=from ; i<dest; ++i)
			{
			a = ds.Tables[0].Rows[i].ItemArray;
			docMaterial.NuevaLinea();
			docMaterial.NuevoTexto("ProveedorID: " + a[0].ToString());
			docMaterial.NuevoTexto("Nombre: " + a[1].ToString());
			docMaterial.NuevoTexto("Direccin: " + a[2].ToString());
			docMaterial.NuevoTexto("Ciudad: " + a[3].ToString());
			docMaterial.NuevoTexto("Codigo Postal: " + a[4].ToString());
			docMaterial.NuevoTexto("Pais: " + a[5].ToString());
			docMaterial.NuevoTexto("e-Mail: " + a[6].ToString());
			docMaterial.NuevoTexto("");
			}
			
			prevDialog.Document = docMaterial;
			prdialog.Document = docMaterial;
			
			docMaterial.PrintPage += new PrintPageEventHandler(docMaterial.ImprimirElementos);
			docMaterial.BeginPrint += new PrintEventHandler (docMaterial.Reajustar);
			
			// Esto esta por ser configurable en fichero XML o DB
			// docMaterial.MuestraPrefsPagina();
			
			
			// Esto tambien deberia ser configurable
			prevDialog.Text = "Previsualizacion del listado de proveedores seleccionados";
			prevDialog.ShowDialog();
			
			if (prdialog.ShowDialog()== DialogResult.OK)
			{
				docMaterial.Print();
			}

			
			}catch(Exception ex){
				FM_Errores.MostrarError("Impresion","No se puede imprimir el listado de proveedores",ex);
			}

		}

		void BtnImprimirListadoClick(object sender, System.EventArgs e)
		{
			this.ImprimirListado(0,ds.Tables[0].Rows.Count);
		}
		
		void BtnImprimirClick(object sender, System.EventArgs e)
		{
			this.ImprimirListado(this.RecPosition,this.RecPosition+1);
		}
		
		void BtnBuscarClick(object sender, System.EventArgs e)
		{
			try{
			adap.SelectCommand = new MySqlCommand("SELECT * FROM proveedores WHERE " + this.cmbBuscar.Text + " like '%"+ this.txtBuscar.Text + "%';",conn);
			ds.Clear();
			adap.Fill(ds,"Proveedores");
			this.RecPosition = 0;
			this.RecCount = ds.Tables[0].Rows.Count;
			MostrarPosicion();
			this.CargarRegistro(0);

			}catch(Exception ex){
				FM_Errores.MostrarError("Busqueda","Ocurri un error al solicitar nuevos datos de la busqueda",ex);
			}
		}
		
	}
}
